# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AccountBalance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'available': 'float',
        'current': 'float',
        'limit': 'float',
        'iso_currency_code': 'str',
        'unofficial_currency_code': 'str'
    }

    attribute_map = {
        'available': 'available',
        'current': 'current',
        'limit': 'limit',
        'iso_currency_code': 'iso_currency_code',
        'unofficial_currency_code': 'unofficial_currency_code'
    }

    def __init__(self, available=None, current=None, limit=None, iso_currency_code=None, unofficial_currency_code=None, local_vars_configuration=None):  # noqa: E501
        """AccountBalance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._available = None
        self._current = None
        self._limit = None
        self._iso_currency_code = None
        self._unofficial_currency_code = None
        self.discriminator = None

        self.available = available
        if current is not None:
            self.current = current
        self.limit = limit
        self.iso_currency_code = iso_currency_code
        self.unofficial_currency_code = unofficial_currency_code

    @property
    def available(self):
        """Gets the available of this AccountBalance.  # noqa: E501

        The amount of funds available to be withdrawn from the account, as determined by the financial institution.  For `credit`-type accounts, the `available` balance typically equals the `limit` less the `current` balance, less any pending outflows plus any pending inflows.  For `depository`-type accounts, the `available` balance typically equals the `current` balance less any pending outflows plus any pending inflows. For `depository`-type accounts, the `available` balance does not include the overdraft limit.  For `investment`-type accounts, the `available` balance is the total cash available to withdraw as presented by the institution.  Note that not all institutions calculate the ` available`  balance. In the event that `available` balance is unavailable, Plaid will return an `available` balance value of `null`.  Available balance may be cached and is not guaranteed to be up-to-date in realtime unless the value was returned by `/accounts/balance/get`.  # noqa: E501

        :return: The available of this AccountBalance.  # noqa: E501
        :rtype: float
        """
        return self._available

    @available.setter
    def available(self, available):
        """Sets the available of this AccountBalance.

        The amount of funds available to be withdrawn from the account, as determined by the financial institution.  For `credit`-type accounts, the `available` balance typically equals the `limit` less the `current` balance, less any pending outflows plus any pending inflows.  For `depository`-type accounts, the `available` balance typically equals the `current` balance less any pending outflows plus any pending inflows. For `depository`-type accounts, the `available` balance does not include the overdraft limit.  For `investment`-type accounts, the `available` balance is the total cash available to withdraw as presented by the institution.  Note that not all institutions calculate the ` available`  balance. In the event that `available` balance is unavailable, Plaid will return an `available` balance value of `null`.  Available balance may be cached and is not guaranteed to be up-to-date in realtime unless the value was returned by `/accounts/balance/get`.  # noqa: E501

        :param available: The available of this AccountBalance.  # noqa: E501
        :type available: float
        """

        self._available = available

    @property
    def current(self):
        """Gets the current of this AccountBalance.  # noqa: E501

        The total amount of funds in or owed by the account.  For `credit`-type accounts, a positive balance indicates the amount owed; a negative amount indicates the lender owing the account holder.  For `loan`-type accounts, the current balance is the principal remaining on the loan.  For `investment`-type accounts, the current balance is the total value of assets as presented by the institution.  Current balance may be cached and is not guaranteed to be up-to-date in realtime unless the value was returned by `/accounts/balance/get`.  # noqa: E501

        :return: The current of this AccountBalance.  # noqa: E501
        :rtype: float
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this AccountBalance.

        The total amount of funds in or owed by the account.  For `credit`-type accounts, a positive balance indicates the amount owed; a negative amount indicates the lender owing the account holder.  For `loan`-type accounts, the current balance is the principal remaining on the loan.  For `investment`-type accounts, the current balance is the total value of assets as presented by the institution.  Current balance may be cached and is not guaranteed to be up-to-date in realtime unless the value was returned by `/accounts/balance/get`.  # noqa: E501

        :param current: The current of this AccountBalance.  # noqa: E501
        :type current: float
        """

        self._current = current

    @property
    def limit(self):
        """Gets the limit of this AccountBalance.  # noqa: E501

        For `credit`-type accounts, this represents the credit limit.   For `depository`-type accounts, this represents the pre-arranged overdraft limit, which is common for current (checking) accounts in Europe.   In North America, this field is typically only available for `credit`-type accounts.  # noqa: E501

        :return: The limit of this AccountBalance.  # noqa: E501
        :rtype: float
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """Sets the limit of this AccountBalance.

        For `credit`-type accounts, this represents the credit limit.   For `depository`-type accounts, this represents the pre-arranged overdraft limit, which is common for current (checking) accounts in Europe.   In North America, this field is typically only available for `credit`-type accounts.  # noqa: E501

        :param limit: The limit of this AccountBalance.  # noqa: E501
        :type limit: float
        """

        self._limit = limit

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this AccountBalance.  # noqa: E501

        The ISO-4217 currency code of the balance. Always null if `unofficial_currency_code` is non-null.  # noqa: E501

        :return: The iso_currency_code of this AccountBalance.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this AccountBalance.

        The ISO-4217 currency code of the balance. Always null if `unofficial_currency_code` is non-null.  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this AccountBalance.  # noqa: E501
        :type iso_currency_code: str
        """

        self._iso_currency_code = iso_currency_code

    @property
    def unofficial_currency_code(self):
        """Gets the unofficial_currency_code of this AccountBalance.  # noqa: E501

        The unofficial currency code associated with the balance. Always null if `iso_currency_code` is non-null. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `unofficial_currency_code`s.  # noqa: E501

        :return: The unofficial_currency_code of this AccountBalance.  # noqa: E501
        :rtype: str
        """
        return self._unofficial_currency_code

    @unofficial_currency_code.setter
    def unofficial_currency_code(self, unofficial_currency_code):
        """Sets the unofficial_currency_code of this AccountBalance.

        The unofficial currency code associated with the balance. Always null if `iso_currency_code` is non-null. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `unofficial_currency_code`s.  # noqa: E501

        :param unofficial_currency_code: The unofficial_currency_code of this AccountBalance.  # noqa: E501
        :type unofficial_currency_code: str
        """

        self._unofficial_currency_code = unofficial_currency_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountBalance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountBalance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class InvestmentTransaction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'investment_transaction_id': 'str',
        'account_id': 'str',
        'security_id': 'str',
        'date': 'str',
        'name': 'str',
        'quantity': 'float',
        'amount': 'float',
        'price': 'float',
        'fees': 'float',
        'type': 'str',
        'subtype': 'StandaloneInvestmentTransactionSubtype',
        'iso_currency_code': 'str',
        'unofficial_currency_code': 'str'
    }

    attribute_map = {
        'investment_transaction_id': 'investment_transaction_id',
        'account_id': 'account_id',
        'security_id': 'security_id',
        'date': 'date',
        'name': 'name',
        'quantity': 'quantity',
        'amount': 'amount',
        'price': 'price',
        'fees': 'fees',
        'type': 'type',
        'subtype': 'subtype',
        'iso_currency_code': 'iso_currency_code',
        'unofficial_currency_code': 'unofficial_currency_code'
    }

    def __init__(self, investment_transaction_id=None, account_id=None, security_id=None, date=None, name=None, quantity=None, amount=None, price=None, fees=None, type=None, subtype=None, iso_currency_code=None, unofficial_currency_code=None, local_vars_configuration=None):  # noqa: E501
        """InvestmentTransaction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._investment_transaction_id = None
        self._account_id = None
        self._security_id = None
        self._date = None
        self._name = None
        self._quantity = None
        self._amount = None
        self._price = None
        self._fees = None
        self._type = None
        self._subtype = None
        self._iso_currency_code = None
        self._unofficial_currency_code = None
        self.discriminator = None

        if investment_transaction_id is not None:
            self.investment_transaction_id = investment_transaction_id
        if account_id is not None:
            self.account_id = account_id
        self.security_id = security_id
        if date is not None:
            self.date = date
        if name is not None:
            self.name = name
        if quantity is not None:
            self.quantity = quantity
        if amount is not None:
            self.amount = amount
        if price is not None:
            self.price = price
        self.fees = fees
        if type is not None:
            self.type = type
        if subtype is not None:
            self.subtype = subtype
        self.iso_currency_code = iso_currency_code
        self.unofficial_currency_code = unofficial_currency_code

    @property
    def investment_transaction_id(self):
        """Gets the investment_transaction_id of this InvestmentTransaction.  # noqa: E501

        The ID of the Investment transaction, unique across all Plaid transactions. Like all Plaid identifiers, the `investment_transaction_id` is case sensitive.  # noqa: E501

        :return: The investment_transaction_id of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._investment_transaction_id

    @investment_transaction_id.setter
    def investment_transaction_id(self, investment_transaction_id):
        """Sets the investment_transaction_id of this InvestmentTransaction.

        The ID of the Investment transaction, unique across all Plaid transactions. Like all Plaid identifiers, the `investment_transaction_id` is case sensitive.  # noqa: E501

        :param investment_transaction_id: The investment_transaction_id of this InvestmentTransaction.  # noqa: E501
        :type investment_transaction_id: str
        """

        self._investment_transaction_id = investment_transaction_id

    @property
    def account_id(self):
        """Gets the account_id of this InvestmentTransaction.  # noqa: E501

        The `account_id` of the account against which this transaction posted.  # noqa: E501

        :return: The account_id of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this InvestmentTransaction.

        The `account_id` of the account against which this transaction posted.  # noqa: E501

        :param account_id: The account_id of this InvestmentTransaction.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def security_id(self):
        """Gets the security_id of this InvestmentTransaction.  # noqa: E501

        The `security_id` to which this transaction is related.  # noqa: E501

        :return: The security_id of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._security_id

    @security_id.setter
    def security_id(self, security_id):
        """Sets the security_id of this InvestmentTransaction.

        The `security_id` to which this transaction is related.  # noqa: E501

        :param security_id: The security_id of this InvestmentTransaction.  # noqa: E501
        :type security_id: str
        """

        self._security_id = security_id

    @property
    def date(self):
        """Gets the date of this InvestmentTransaction.  # noqa: E501

        The ISO-8601 posting date for the transaction, or transacted date for pending transactions.  # noqa: E501

        :return: The date of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this InvestmentTransaction.

        The ISO-8601 posting date for the transaction, or transacted date for pending transactions.  # noqa: E501

        :param date: The date of this InvestmentTransaction.  # noqa: E501
        :type date: str
        """

        self._date = date

    @property
    def name(self):
        """Gets the name of this InvestmentTransaction.  # noqa: E501

        The institution’s description of the transaction.  # noqa: E501

        :return: The name of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this InvestmentTransaction.

        The institution’s description of the transaction.  # noqa: E501

        :param name: The name of this InvestmentTransaction.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def quantity(self):
        """Gets the quantity of this InvestmentTransaction.  # noqa: E501

        The number of units of the security involved in this transactions  # noqa: E501

        :return: The quantity of this InvestmentTransaction.  # noqa: E501
        :rtype: float
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """Sets the quantity of this InvestmentTransaction.

        The number of units of the security involved in this transactions  # noqa: E501

        :param quantity: The quantity of this InvestmentTransaction.  # noqa: E501
        :type quantity: float
        """

        self._quantity = quantity

    @property
    def amount(self):
        """Gets the amount of this InvestmentTransaction.  # noqa: E501

        The complete value of the transaction. Positive values when cash is debited, e.g. purchases of stock; negative values when cash is credited, e.g. sales of stock. Treatment remains the same for cash-only movements unassociated with securities.  # noqa: E501

        :return: The amount of this InvestmentTransaction.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this InvestmentTransaction.

        The complete value of the transaction. Positive values when cash is debited, e.g. purchases of stock; negative values when cash is credited, e.g. sales of stock. Treatment remains the same for cash-only movements unassociated with securities.  # noqa: E501

        :param amount: The amount of this InvestmentTransaction.  # noqa: E501
        :type amount: float
        """

        self._amount = amount

    @property
    def price(self):
        """Gets the price of this InvestmentTransaction.  # noqa: E501

        The price of the security at which this transaction occurred.  # noqa: E501

        :return: The price of this InvestmentTransaction.  # noqa: E501
        :rtype: float
        """
        return self._price

    @price.setter
    def price(self, price):
        """Sets the price of this InvestmentTransaction.

        The price of the security at which this transaction occurred.  # noqa: E501

        :param price: The price of this InvestmentTransaction.  # noqa: E501
        :type price: float
        """

        self._price = price

    @property
    def fees(self):
        """Gets the fees of this InvestmentTransaction.  # noqa: E501

        The combined value of all fees applied to this transaction  # noqa: E501

        :return: The fees of this InvestmentTransaction.  # noqa: E501
        :rtype: float
        """
        return self._fees

    @fees.setter
    def fees(self, fees):
        """Sets the fees of this InvestmentTransaction.

        The combined value of all fees applied to this transaction  # noqa: E501

        :param fees: The fees of this InvestmentTransaction.  # noqa: E501
        :type fees: float
        """

        self._fees = fees

    @property
    def type(self):
        """Gets the type of this InvestmentTransaction.  # noqa: E501

        Value is one of the following:   `buy`: Buying an investment `sell`: Selling an investment  `cancel`: A cancellation of a pending transaction  `cash`: Activity that modifies a cash position  `fee`: A fee on the account  `transfer`: Activity which modifies a position, but not through buy/sell activity e.g. options exercise, portfolio transfer  # noqa: E501

        :return: The type of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InvestmentTransaction.

        Value is one of the following:   `buy`: Buying an investment `sell`: Selling an investment  `cancel`: A cancellation of a pending transaction  `cash`: Activity that modifies a cash position  `fee`: A fee on the account  `transfer`: Activity which modifies a position, but not through buy/sell activity e.g. options exercise, portfolio transfer  # noqa: E501

        :param type: The type of this InvestmentTransaction.  # noqa: E501
        :type type: str
        """
        allowed_values = ["buy", "sell", "cancel", "cash", "fee", "transfer"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def subtype(self):
        """Gets the subtype of this InvestmentTransaction.  # noqa: E501


        :return: The subtype of this InvestmentTransaction.  # noqa: E501
        :rtype: StandaloneInvestmentTransactionSubtype
        """
        return self._subtype

    @subtype.setter
    def subtype(self, subtype):
        """Sets the subtype of this InvestmentTransaction.


        :param subtype: The subtype of this InvestmentTransaction.  # noqa: E501
        :type subtype: StandaloneInvestmentTransactionSubtype
        """

        self._subtype = subtype

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this InvestmentTransaction.  # noqa: E501

        The ISO-4217 currency code of the transaction. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :return: The iso_currency_code of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this InvestmentTransaction.

        The ISO-4217 currency code of the transaction. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this InvestmentTransaction.  # noqa: E501
        :type iso_currency_code: str
        """

        self._iso_currency_code = iso_currency_code

    @property
    def unofficial_currency_code(self):
        """Gets the unofficial_currency_code of this InvestmentTransaction.  # noqa: E501

        The unofficial currency code associated with the holding. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :return: The unofficial_currency_code of this InvestmentTransaction.  # noqa: E501
        :rtype: str
        """
        return self._unofficial_currency_code

    @unofficial_currency_code.setter
    def unofficial_currency_code(self, unofficial_currency_code):
        """Sets the unofficial_currency_code of this InvestmentTransaction.

        The unofficial currency code associated with the holding. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :param unofficial_currency_code: The unofficial_currency_code of this InvestmentTransaction.  # noqa: E501
        :type unofficial_currency_code: str
        """

        self._unofficial_currency_code = unofficial_currency_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InvestmentTransaction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InvestmentTransaction):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AssetReportGetResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'report': 'AssetReport',
        'warnings': 'list[Warning]',
        'request_id': 'str'
    }

    attribute_map = {
        'report': 'report',
        'warnings': 'warnings',
        'request_id': 'request_id'
    }

    def __init__(self, report=None, warnings=None, request_id=None, local_vars_configuration=None):  # noqa: E501
        """AssetReportGetResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._report = None
        self._warnings = None
        self._request_id = None
        self.discriminator = None

        if report is not None:
            self.report = report
        if warnings is not None:
            self.warnings = warnings
        if request_id is not None:
            self.request_id = request_id

    @property
    def report(self):
        """Gets the report of this AssetReportGetResponse.  # noqa: E501


        :return: The report of this AssetReportGetResponse.  # noqa: E501
        :rtype: AssetReport
        """
        return self._report

    @report.setter
    def report(self, report):
        """Sets the report of this AssetReportGetResponse.


        :param report: The report of this AssetReportGetResponse.  # noqa: E501
        :type report: AssetReport
        """

        self._report = report

    @property
    def warnings(self):
        """Gets the warnings of this AssetReportGetResponse.  # noqa: E501

        If the Asset Report generation was successful but identity information cannot be returned, this array will contain information about the errors causing identity information to be missing  # noqa: E501

        :return: The warnings of this AssetReportGetResponse.  # noqa: E501
        :rtype: list[Warning]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """Sets the warnings of this AssetReportGetResponse.

        If the Asset Report generation was successful but identity information cannot be returned, this array will contain information about the errors causing identity information to be missing  # noqa: E501

        :param warnings: The warnings of this AssetReportGetResponse.  # noqa: E501
        :type warnings: list[Warning]
        """

        self._warnings = warnings

    @property
    def request_id(self):
        """Gets the request_id of this AssetReportGetResponse.  # noqa: E501

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :return: The request_id of this AssetReportGetResponse.  # noqa: E501
        :rtype: str
        """
        return self._request_id

    @request_id.setter
    def request_id(self, request_id):
        """Sets the request_id of this AssetReportGetResponse.

        A unique identifier for the request, which can be used for troubleshooting. This identifier, like all Plaid identifiers, is case sensitive.  # noqa: E501

        :param request_id: The request_id of this AssetReportGetResponse.  # noqa: E501
        :type request_id: str
        """

        self._request_id = request_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AssetReportGetResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AssetReportGetResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class NumbersEFT(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'account': 'str',
        'institution': 'str',
        'branch': 'str'
    }

    attribute_map = {
        'account_id': 'account_id',
        'account': 'account',
        'institution': 'institution',
        'branch': 'branch'
    }

    def __init__(self, account_id=None, account=None, institution=None, branch=None, local_vars_configuration=None):  # noqa: E501
        """NumbersEFT - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._account = None
        self._institution = None
        self._branch = None
        self.discriminator = None

        if account_id is not None:
            self.account_id = account_id
        if account is not None:
            self.account = account
        if institution is not None:
            self.institution = institution
        if branch is not None:
            self.branch = branch

    @property
    def account_id(self):
        """Gets the account_id of this NumbersEFT.  # noqa: E501

        The Plaid account ID associated with the account numbers  # noqa: E501

        :return: The account_id of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this NumbersEFT.

        The Plaid account ID associated with the account numbers  # noqa: E501

        :param account_id: The account_id of this NumbersEFT.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def account(self):
        """Gets the account of this NumbersEFT.  # noqa: E501

        The EFT account number for the account  # noqa: E501

        :return: The account of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this NumbersEFT.

        The EFT account number for the account  # noqa: E501

        :param account: The account of this NumbersEFT.  # noqa: E501
        :type account: str
        """

        self._account = account

    @property
    def institution(self):
        """Gets the institution of this NumbersEFT.  # noqa: E501

        The EFT institution number for the account  # noqa: E501

        :return: The institution of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._institution

    @institution.setter
    def institution(self, institution):
        """Sets the institution of this NumbersEFT.

        The EFT institution number for the account  # noqa: E501

        :param institution: The institution of this NumbersEFT.  # noqa: E501
        :type institution: str
        """

        self._institution = institution

    @property
    def branch(self):
        """Gets the branch of this NumbersEFT.  # noqa: E501

        The EFT branch number for the account  # noqa: E501

        :return: The branch of this NumbersEFT.  # noqa: E501
        :rtype: str
        """
        return self._branch

    @branch.setter
    def branch(self, branch):
        """Sets the branch of this NumbersEFT.

        The EFT branch number for the account  # noqa: E501

        :param branch: The branch of this NumbersEFT.  # noqa: E501
        :type branch: str
        """

        self._branch = branch

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, NumbersEFT):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, NumbersEFT):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class MortgageLiability(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account_id': 'str',
        'account_number': 'str',
        'current_late_fee': 'float',
        'escrow_balance': 'float',
        'has_pmi': 'bool',
        'has_prepayment_penalty': 'bool',
        'interest_rate': 'MortgageInterestRate',
        'last_payment_amount': 'float',
        'last_payment_date': 'str',
        'loan_type_description': 'str',
        'loan_term': 'str',
        'maturity_date': 'str',
        'next_monthly_payment_amount': 'float',
        'next_payment_due_date': 'str',
        'origination_date': 'str',
        'origination_principal_amount': 'float',
        'past_due_amount': 'float',
        'property_address': 'MortgagePropertyAddress',
        'ytd_interest_paid': 'float',
        'ytd_principal_paid': 'float'
    }

    attribute_map = {
        'account_id': 'account_id',
        'account_number': 'account_number',
        'current_late_fee': 'current_late_fee',
        'escrow_balance': 'escrow_balance',
        'has_pmi': 'has_pmi',
        'has_prepayment_penalty': 'has_prepayment_penalty',
        'interest_rate': 'interest_rate',
        'last_payment_amount': 'last_payment_amount',
        'last_payment_date': 'last_payment_date',
        'loan_type_description': 'loan_type_description',
        'loan_term': 'loan_term',
        'maturity_date': 'maturity_date',
        'next_monthly_payment_amount': 'next_monthly_payment_amount',
        'next_payment_due_date': 'next_payment_due_date',
        'origination_date': 'origination_date',
        'origination_principal_amount': 'origination_principal_amount',
        'past_due_amount': 'past_due_amount',
        'property_address': 'property_address',
        'ytd_interest_paid': 'ytd_interest_paid',
        'ytd_principal_paid': 'ytd_principal_paid'
    }

    def __init__(self, account_id=None, account_number=None, current_late_fee=None, escrow_balance=None, has_pmi=None, has_prepayment_penalty=None, interest_rate=None, last_payment_amount=None, last_payment_date=None, loan_type_description=None, loan_term=None, maturity_date=None, next_monthly_payment_amount=None, next_payment_due_date=None, origination_date=None, origination_principal_amount=None, past_due_amount=None, property_address=None, ytd_interest_paid=None, ytd_principal_paid=None, local_vars_configuration=None):  # noqa: E501
        """MortgageLiability - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account_id = None
        self._account_number = None
        self._current_late_fee = None
        self._escrow_balance = None
        self._has_pmi = None
        self._has_prepayment_penalty = None
        self._interest_rate = None
        self._last_payment_amount = None
        self._last_payment_date = None
        self._loan_type_description = None
        self._loan_term = None
        self._maturity_date = None
        self._next_monthly_payment_amount = None
        self._next_payment_due_date = None
        self._origination_date = None
        self._origination_principal_amount = None
        self._past_due_amount = None
        self._property_address = None
        self._ytd_interest_paid = None
        self._ytd_principal_paid = None
        self.discriminator = None

        self.account_id = account_id
        if account_number is not None:
            self.account_number = account_number
        self.current_late_fee = current_late_fee
        self.escrow_balance = escrow_balance
        self.has_pmi = has_pmi
        self.has_prepayment_penalty = has_prepayment_penalty
        if interest_rate is not None:
            self.interest_rate = interest_rate
        self.last_payment_amount = last_payment_amount
        self.last_payment_date = last_payment_date
        self.loan_type_description = loan_type_description
        self.loan_term = loan_term
        self.maturity_date = maturity_date
        self.next_monthly_payment_amount = next_monthly_payment_amount
        self.next_payment_due_date = next_payment_due_date
        self.origination_date = origination_date
        self.origination_principal_amount = origination_principal_amount
        self.past_due_amount = past_due_amount
        if property_address is not None:
            self.property_address = property_address
        self.ytd_interest_paid = ytd_interest_paid
        self.ytd_principal_paid = ytd_principal_paid

    @property
    def account_id(self):
        """Gets the account_id of this MortgageLiability.  # noqa: E501

        The ID of the account that this liability belongs to.  # noqa: E501

        :return: The account_id of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this MortgageLiability.

        The ID of the account that this liability belongs to.  # noqa: E501

        :param account_id: The account_id of this MortgageLiability.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def account_number(self):
        """Gets the account_number of this MortgageLiability.  # noqa: E501

        The account number of the loan.  # noqa: E501

        :return: The account_number of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._account_number

    @account_number.setter
    def account_number(self, account_number):
        """Sets the account_number of this MortgageLiability.

        The account number of the loan.  # noqa: E501

        :param account_number: The account_number of this MortgageLiability.  # noqa: E501
        :type account_number: str
        """

        self._account_number = account_number

    @property
    def current_late_fee(self):
        """Gets the current_late_fee of this MortgageLiability.  # noqa: E501

        The current outstanding amount charged for late payment.  # noqa: E501

        :return: The current_late_fee of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._current_late_fee

    @current_late_fee.setter
    def current_late_fee(self, current_late_fee):
        """Sets the current_late_fee of this MortgageLiability.

        The current outstanding amount charged for late payment.  # noqa: E501

        :param current_late_fee: The current_late_fee of this MortgageLiability.  # noqa: E501
        :type current_late_fee: float
        """

        self._current_late_fee = current_late_fee

    @property
    def escrow_balance(self):
        """Gets the escrow_balance of this MortgageLiability.  # noqa: E501

        Total amount held in escrow to pay taxes and insurance on behalf of the borrower.  # noqa: E501

        :return: The escrow_balance of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._escrow_balance

    @escrow_balance.setter
    def escrow_balance(self, escrow_balance):
        """Sets the escrow_balance of this MortgageLiability.

        Total amount held in escrow to pay taxes and insurance on behalf of the borrower.  # noqa: E501

        :param escrow_balance: The escrow_balance of this MortgageLiability.  # noqa: E501
        :type escrow_balance: float
        """

        self._escrow_balance = escrow_balance

    @property
    def has_pmi(self):
        """Gets the has_pmi of this MortgageLiability.  # noqa: E501

        Indicates whether the borrower has private mortgage insurance in effect.  # noqa: E501

        :return: The has_pmi of this MortgageLiability.  # noqa: E501
        :rtype: bool
        """
        return self._has_pmi

    @has_pmi.setter
    def has_pmi(self, has_pmi):
        """Sets the has_pmi of this MortgageLiability.

        Indicates whether the borrower has private mortgage insurance in effect.  # noqa: E501

        :param has_pmi: The has_pmi of this MortgageLiability.  # noqa: E501
        :type has_pmi: bool
        """

        self._has_pmi = has_pmi

    @property
    def has_prepayment_penalty(self):
        """Gets the has_prepayment_penalty of this MortgageLiability.  # noqa: E501

        Indicates whether the borrower will pay a penalty for early payoff of mortgage.  # noqa: E501

        :return: The has_prepayment_penalty of this MortgageLiability.  # noqa: E501
        :rtype: bool
        """
        return self._has_prepayment_penalty

    @has_prepayment_penalty.setter
    def has_prepayment_penalty(self, has_prepayment_penalty):
        """Sets the has_prepayment_penalty of this MortgageLiability.

        Indicates whether the borrower will pay a penalty for early payoff of mortgage.  # noqa: E501

        :param has_prepayment_penalty: The has_prepayment_penalty of this MortgageLiability.  # noqa: E501
        :type has_prepayment_penalty: bool
        """

        self._has_prepayment_penalty = has_prepayment_penalty

    @property
    def interest_rate(self):
        """Gets the interest_rate of this MortgageLiability.  # noqa: E501


        :return: The interest_rate of this MortgageLiability.  # noqa: E501
        :rtype: MortgageInterestRate
        """
        return self._interest_rate

    @interest_rate.setter
    def interest_rate(self, interest_rate):
        """Sets the interest_rate of this MortgageLiability.


        :param interest_rate: The interest_rate of this MortgageLiability.  # noqa: E501
        :type interest_rate: MortgageInterestRate
        """

        self._interest_rate = interest_rate

    @property
    def last_payment_amount(self):
        """Gets the last_payment_amount of this MortgageLiability.  # noqa: E501

        The amount of the last payment.  # noqa: E501

        :return: The last_payment_amount of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._last_payment_amount

    @last_payment_amount.setter
    def last_payment_amount(self, last_payment_amount):
        """Sets the last_payment_amount of this MortgageLiability.

        The amount of the last payment.  # noqa: E501

        :param last_payment_amount: The last_payment_amount of this MortgageLiability.  # noqa: E501
        :type last_payment_amount: float
        """

        self._last_payment_amount = last_payment_amount

    @property
    def last_payment_date(self):
        """Gets the last_payment_date of this MortgageLiability.  # noqa: E501

        The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The last_payment_date of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._last_payment_date

    @last_payment_date.setter
    def last_payment_date(self, last_payment_date):
        """Sets the last_payment_date of this MortgageLiability.

        The date of the last payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param last_payment_date: The last_payment_date of this MortgageLiability.  # noqa: E501
        :type last_payment_date: str
        """

        self._last_payment_date = last_payment_date

    @property
    def loan_type_description(self):
        """Gets the loan_type_description of this MortgageLiability.  # noqa: E501

        Type of mortgage (i.e. `conventional`, `fixed`, `variable`).  # noqa: E501

        :return: The loan_type_description of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._loan_type_description

    @loan_type_description.setter
    def loan_type_description(self, loan_type_description):
        """Sets the loan_type_description of this MortgageLiability.

        Type of mortgage (i.e. `conventional`, `fixed`, `variable`).  # noqa: E501

        :param loan_type_description: The loan_type_description of this MortgageLiability.  # noqa: E501
        :type loan_type_description: str
        """

        self._loan_type_description = loan_type_description

    @property
    def loan_term(self):
        """Gets the loan_term of this MortgageLiability.  # noqa: E501

        Full duration of mortgage as at origination. (`10yr`, `15yr`, `30yr`)  # noqa: E501

        :return: The loan_term of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._loan_term

    @loan_term.setter
    def loan_term(self, loan_term):
        """Sets the loan_term of this MortgageLiability.

        Full duration of mortgage as at origination. (`10yr`, `15yr`, `30yr`)  # noqa: E501

        :param loan_term: The loan_term of this MortgageLiability.  # noqa: E501
        :type loan_term: str
        """

        self._loan_term = loan_term

    @property
    def maturity_date(self):
        """Gets the maturity_date of this MortgageLiability.  # noqa: E501

        Original date on which mortgage is due in full. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The maturity_date of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._maturity_date

    @maturity_date.setter
    def maturity_date(self, maturity_date):
        """Sets the maturity_date of this MortgageLiability.

        Original date on which mortgage is due in full. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param maturity_date: The maturity_date of this MortgageLiability.  # noqa: E501
        :type maturity_date: str
        """

        self._maturity_date = maturity_date

    @property
    def next_monthly_payment_amount(self):
        """Gets the next_monthly_payment_amount of this MortgageLiability.  # noqa: E501

        The amount of the next payment.  # noqa: E501

        :return: The next_monthly_payment_amount of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._next_monthly_payment_amount

    @next_monthly_payment_amount.setter
    def next_monthly_payment_amount(self, next_monthly_payment_amount):
        """Sets the next_monthly_payment_amount of this MortgageLiability.

        The amount of the next payment.  # noqa: E501

        :param next_monthly_payment_amount: The next_monthly_payment_amount of this MortgageLiability.  # noqa: E501
        :type next_monthly_payment_amount: float
        """

        self._next_monthly_payment_amount = next_monthly_payment_amount

    @property
    def next_payment_due_date(self):
        """Gets the next_payment_due_date of this MortgageLiability.  # noqa: E501

        The due date for the next payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The next_payment_due_date of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._next_payment_due_date

    @next_payment_due_date.setter
    def next_payment_due_date(self, next_payment_due_date):
        """Sets the next_payment_due_date of this MortgageLiability.

        The due date for the next payment. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param next_payment_due_date: The next_payment_due_date of this MortgageLiability.  # noqa: E501
        :type next_payment_due_date: str
        """

        self._next_payment_due_date = next_payment_due_date

    @property
    def origination_date(self):
        """Gets the origination_date of this MortgageLiability.  # noqa: E501

        The date on which the loan was initially lent. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :return: The origination_date of this MortgageLiability.  # noqa: E501
        :rtype: str
        """
        return self._origination_date

    @origination_date.setter
    def origination_date(self, origination_date):
        """Sets the origination_date of this MortgageLiability.

        The date on which the loan was initially lent. Dates are returned in an ISO 8601 format (YYYY-MM-DD).  # noqa: E501

        :param origination_date: The origination_date of this MortgageLiability.  # noqa: E501
        :type origination_date: str
        """

        self._origination_date = origination_date

    @property
    def origination_principal_amount(self):
        """Gets the origination_principal_amount of this MortgageLiability.  # noqa: E501

        The original principal balance of the mortgage.  # noqa: E501

        :return: The origination_principal_amount of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._origination_principal_amount

    @origination_principal_amount.setter
    def origination_principal_amount(self, origination_principal_amount):
        """Sets the origination_principal_amount of this MortgageLiability.

        The original principal balance of the mortgage.  # noqa: E501

        :param origination_principal_amount: The origination_principal_amount of this MortgageLiability.  # noqa: E501
        :type origination_principal_amount: float
        """

        self._origination_principal_amount = origination_principal_amount

    @property
    def past_due_amount(self):
        """Gets the past_due_amount of this MortgageLiability.  # noqa: E501

        Amount of loan (principal + interest) past due for payment.  # noqa: E501

        :return: The past_due_amount of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._past_due_amount

    @past_due_amount.setter
    def past_due_amount(self, past_due_amount):
        """Sets the past_due_amount of this MortgageLiability.

        Amount of loan (principal + interest) past due for payment.  # noqa: E501

        :param past_due_amount: The past_due_amount of this MortgageLiability.  # noqa: E501
        :type past_due_amount: float
        """

        self._past_due_amount = past_due_amount

    @property
    def property_address(self):
        """Gets the property_address of this MortgageLiability.  # noqa: E501


        :return: The property_address of this MortgageLiability.  # noqa: E501
        :rtype: MortgagePropertyAddress
        """
        return self._property_address

    @property_address.setter
    def property_address(self, property_address):
        """Sets the property_address of this MortgageLiability.


        :param property_address: The property_address of this MortgageLiability.  # noqa: E501
        :type property_address: MortgagePropertyAddress
        """

        self._property_address = property_address

    @property
    def ytd_interest_paid(self):
        """Gets the ytd_interest_paid of this MortgageLiability.  # noqa: E501

        The year to date (YTD) interest paid.  # noqa: E501

        :return: The ytd_interest_paid of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._ytd_interest_paid

    @ytd_interest_paid.setter
    def ytd_interest_paid(self, ytd_interest_paid):
        """Sets the ytd_interest_paid of this MortgageLiability.

        The year to date (YTD) interest paid.  # noqa: E501

        :param ytd_interest_paid: The ytd_interest_paid of this MortgageLiability.  # noqa: E501
        :type ytd_interest_paid: float
        """

        self._ytd_interest_paid = ytd_interest_paid

    @property
    def ytd_principal_paid(self):
        """Gets the ytd_principal_paid of this MortgageLiability.  # noqa: E501

        The YTD principal paid.  # noqa: E501

        :return: The ytd_principal_paid of this MortgageLiability.  # noqa: E501
        :rtype: float
        """
        return self._ytd_principal_paid

    @ytd_principal_paid.setter
    def ytd_principal_paid(self, ytd_principal_paid):
        """Sets the ytd_principal_paid of this MortgageLiability.

        The YTD principal paid.  # noqa: E501

        :param ytd_principal_paid: The ytd_principal_paid of this MortgageLiability.  # noqa: E501
        :type ytd_principal_paid: float
        """

        self._ytd_principal_paid = ytd_principal_paid

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, MortgageLiability):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, MortgageLiability):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class AccountAssetsAllOf(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'days_available': 'float',
        'transactions': 'list[Transaction]',
        'owners': 'list[Owner]',
        'historical_balances': 'list[HistoricalBalance]'
    }

    attribute_map = {
        'days_available': 'days_available',
        'transactions': 'transactions',
        'owners': 'owners',
        'historical_balances': 'historical_balances'
    }

    def __init__(self, days_available=None, transactions=None, owners=None, historical_balances=None, local_vars_configuration=None):  # noqa: E501
        """AccountAssetsAllOf - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._days_available = None
        self._transactions = None
        self._owners = None
        self._historical_balances = None
        self.discriminator = None

        self.days_available = days_available
        self.transactions = transactions
        if owners is not None:
            self.owners = owners
        self.historical_balances = historical_balances

    @property
    def days_available(self):
        """Gets the days_available of this AccountAssetsAllOf.  # noqa: E501

        The duration of transaction history available for this Item, typically defined as the time since the date of the earliest transaction in that account. Only returned by Assets endpoints.  # noqa: E501

        :return: The days_available of this AccountAssetsAllOf.  # noqa: E501
        :rtype: float
        """
        return self._days_available

    @days_available.setter
    def days_available(self, days_available):
        """Sets the days_available of this AccountAssetsAllOf.

        The duration of transaction history available for this Item, typically defined as the time since the date of the earliest transaction in that account. Only returned by Assets endpoints.  # noqa: E501

        :param days_available: The days_available of this AccountAssetsAllOf.  # noqa: E501
        :type days_available: float
        """

        self._days_available = days_available

    @property
    def transactions(self):
        """Gets the transactions of this AccountAssetsAllOf.  # noqa: E501

        Transaction history associated with the account. Only returned by Assets endpoints. Transaction history returned by endpoints such as `/transactions/get` or `/investments/transactions/get` will be returned in the top-level `transactions` field instead.  # noqa: E501

        :return: The transactions of this AccountAssetsAllOf.  # noqa: E501
        :rtype: list[Transaction]
        """
        return self._transactions

    @transactions.setter
    def transactions(self, transactions):
        """Sets the transactions of this AccountAssetsAllOf.

        Transaction history associated with the account. Only returned by Assets endpoints. Transaction history returned by endpoints such as `/transactions/get` or `/investments/transactions/get` will be returned in the top-level `transactions` field instead.  # noqa: E501

        :param transactions: The transactions of this AccountAssetsAllOf.  # noqa: E501
        :type transactions: list[Transaction]
        """

        self._transactions = transactions

    @property
    def owners(self):
        """Gets the owners of this AccountAssetsAllOf.  # noqa: E501

        Data returned by the financial institution about the account owner or owners. Only returned by Identity or Assets endpoints. Multiple owners on a single account will be represented in the same `owner` object, not in multiple owner objects within the array.  # noqa: E501

        :return: The owners of this AccountAssetsAllOf.  # noqa: E501
        :rtype: list[Owner]
        """
        return self._owners

    @owners.setter
    def owners(self, owners):
        """Sets the owners of this AccountAssetsAllOf.

        Data returned by the financial institution about the account owner or owners. Only returned by Identity or Assets endpoints. Multiple owners on a single account will be represented in the same `owner` object, not in multiple owner objects within the array.  # noqa: E501

        :param owners: The owners of this AccountAssetsAllOf.  # noqa: E501
        :type owners: list[Owner]
        """

        self._owners = owners

    @property
    def historical_balances(self):
        """Gets the historical_balances of this AccountAssetsAllOf.  # noqa: E501

        Calculated data about the historical balances on the account. Only returned by Assets endpoints.  # noqa: E501

        :return: The historical_balances of this AccountAssetsAllOf.  # noqa: E501
        :rtype: list[HistoricalBalance]
        """
        return self._historical_balances

    @historical_balances.setter
    def historical_balances(self, historical_balances):
        """Sets the historical_balances of this AccountAssetsAllOf.

        Calculated data about the historical balances on the account. Only returned by Assets endpoints.  # noqa: E501

        :param historical_balances: The historical_balances of this AccountAssetsAllOf.  # noqa: E501
        :type historical_balances: list[HistoricalBalance]
        """

        self._historical_balances = historical_balances

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AccountAssetsAllOf):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, AccountAssetsAllOf):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class ProductStatusBreakdown(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'success': 'float',
        'error_plaid': 'float',
        'error_institution': 'float',
        'refresh_interval': 'str'
    }

    attribute_map = {
        'success': 'success',
        'error_plaid': 'error_plaid',
        'error_institution': 'error_institution',
        'refresh_interval': 'refresh_interval'
    }

    def __init__(self, success=None, error_plaid=None, error_institution=None, refresh_interval=None, local_vars_configuration=None):  # noqa: E501
        """ProductStatusBreakdown - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._success = None
        self._error_plaid = None
        self._error_institution = None
        self._refresh_interval = None
        self.discriminator = None

        if success is not None:
            self.success = success
        if error_plaid is not None:
            self.error_plaid = error_plaid
        if error_institution is not None:
            self.error_institution = error_institution
        self.refresh_interval = refresh_interval

    @property
    def success(self):
        """Gets the success of this ProductStatusBreakdown.  # noqa: E501

        The percentage of login attempts that are successful, expressed as a decimal.  # noqa: E501

        :return: The success of this ProductStatusBreakdown.  # noqa: E501
        :rtype: float
        """
        return self._success

    @success.setter
    def success(self, success):
        """Sets the success of this ProductStatusBreakdown.

        The percentage of login attempts that are successful, expressed as a decimal.  # noqa: E501

        :param success: The success of this ProductStatusBreakdown.  # noqa: E501
        :type success: float
        """

        self._success = success

    @property
    def error_plaid(self):
        """Gets the error_plaid of this ProductStatusBreakdown.  # noqa: E501

        The percentage of logins that are failing due to an internal Plaid issue, expressed as a decimal.   # noqa: E501

        :return: The error_plaid of this ProductStatusBreakdown.  # noqa: E501
        :rtype: float
        """
        return self._error_plaid

    @error_plaid.setter
    def error_plaid(self, error_plaid):
        """Sets the error_plaid of this ProductStatusBreakdown.

        The percentage of logins that are failing due to an internal Plaid issue, expressed as a decimal.   # noqa: E501

        :param error_plaid: The error_plaid of this ProductStatusBreakdown.  # noqa: E501
        :type error_plaid: float
        """

        self._error_plaid = error_plaid

    @property
    def error_institution(self):
        """Gets the error_institution of this ProductStatusBreakdown.  # noqa: E501

        The percentage of logins that are failing due to an issue in the institution's system, expressed as a decimal.  # noqa: E501

        :return: The error_institution of this ProductStatusBreakdown.  # noqa: E501
        :rtype: float
        """
        return self._error_institution

    @error_institution.setter
    def error_institution(self, error_institution):
        """Sets the error_institution of this ProductStatusBreakdown.

        The percentage of logins that are failing due to an issue in the institution's system, expressed as a decimal.  # noqa: E501

        :param error_institution: The error_institution of this ProductStatusBreakdown.  # noqa: E501
        :type error_institution: float
        """

        self._error_institution = error_institution

    @property
    def refresh_interval(self):
        """Gets the refresh_interval of this ProductStatusBreakdown.  # noqa: E501

        The `refresh_interval` may be `DELAYED` or `STOPPED` even when the success rate is high. This value is only returned for Transactions status breakdowns.  # noqa: E501

        :return: The refresh_interval of this ProductStatusBreakdown.  # noqa: E501
        :rtype: str
        """
        return self._refresh_interval

    @refresh_interval.setter
    def refresh_interval(self, refresh_interval):
        """Sets the refresh_interval of this ProductStatusBreakdown.

        The `refresh_interval` may be `DELAYED` or `STOPPED` even when the success rate is high. This value is only returned for Transactions status breakdowns.  # noqa: E501

        :param refresh_interval: The refresh_interval of this ProductStatusBreakdown.  # noqa: E501
        :type refresh_interval: str
        """
        allowed_values = [None,"NORMAL", "DELAYED", "STOPPED"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and refresh_interval not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `refresh_interval` ({0}), must be one of {1}"  # noqa: E501
                .format(refresh_interval, allowed_values)
            )

        self._refresh_interval = refresh_interval

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ProductStatusBreakdown):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ProductStatusBreakdown):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class HistoricalBalance(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'date': 'str',
        'current': 'str',
        'iso_currency_code': 'str',
        'unofficial_currency_code': 'str'
    }

    attribute_map = {
        'date': 'date',
        'current': 'current',
        'iso_currency_code': 'iso_currency_code',
        'unofficial_currency_code': 'unofficial_currency_code'
    }

    def __init__(self, date=None, current=None, iso_currency_code=None, unofficial_currency_code=None, local_vars_configuration=None):  # noqa: E501
        """HistoricalBalance - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._date = None
        self._current = None
        self._iso_currency_code = None
        self._unofficial_currency_code = None
        self.discriminator = None

        if date is not None:
            self.date = date
        if current is not None:
            self.current = current
        self.iso_currency_code = iso_currency_code
        self.unofficial_currency_code = unofficial_currency_code

    @property
    def date(self):
        """Gets the date of this HistoricalBalance.  # noqa: E501

        The date of the calculated historical balance, in an ISO 8601 format (YYYY-MM-DD)  # noqa: E501

        :return: The date of this HistoricalBalance.  # noqa: E501
        :rtype: str
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this HistoricalBalance.

        The date of the calculated historical balance, in an ISO 8601 format (YYYY-MM-DD)  # noqa: E501

        :param date: The date of this HistoricalBalance.  # noqa: E501
        :type date: str
        """

        self._date = date

    @property
    def current(self):
        """Gets the current of this HistoricalBalance.  # noqa: E501

        The total amount of funds in the account, calculated from the `current` balance in the `balance` object by subtracting inflows and adding back outflows according to the posted date of each transaction.  If the account has any pending transactions, historical balance amounts on or after the date of the earliest pending transaction may differ if retrieved in subsequent Asset Reports as a result of those pending transactions posting.  # noqa: E501

        :return: The current of this HistoricalBalance.  # noqa: E501
        :rtype: str
        """
        return self._current

    @current.setter
    def current(self, current):
        """Sets the current of this HistoricalBalance.

        The total amount of funds in the account, calculated from the `current` balance in the `balance` object by subtracting inflows and adding back outflows according to the posted date of each transaction.  If the account has any pending transactions, historical balance amounts on or after the date of the earliest pending transaction may differ if retrieved in subsequent Asset Reports as a result of those pending transactions posting.  # noqa: E501

        :param current: The current of this HistoricalBalance.  # noqa: E501
        :type current: str
        """

        self._current = current

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this HistoricalBalance.  # noqa: E501

        The ISO-4217 currency code of the balance. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :return: The iso_currency_code of this HistoricalBalance.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this HistoricalBalance.

        The ISO-4217 currency code of the balance. Always `null` if `unofficial_currency_code` is non-`null`.  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this HistoricalBalance.  # noqa: E501
        :type iso_currency_code: str
        """

        self._iso_currency_code = iso_currency_code

    @property
    def unofficial_currency_code(self):
        """Gets the unofficial_currency_code of this HistoricalBalance.  # noqa: E501

        The unofficial currency code associated with the balance. Always `null` if `iso_currency_code` is non-`null`.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :return: The unofficial_currency_code of this HistoricalBalance.  # noqa: E501
        :rtype: str
        """
        return self._unofficial_currency_code

    @unofficial_currency_code.setter
    def unofficial_currency_code(self, unofficial_currency_code):
        """Sets the unofficial_currency_code of this HistoricalBalance.

        The unofficial currency code associated with the balance. Always `null` if `iso_currency_code` is non-`null`.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :param unofficial_currency_code: The unofficial_currency_code of this HistoricalBalance.  # noqa: E501
        :type unofficial_currency_code: str
        """

        self._unofficial_currency_code = unofficial_currency_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HistoricalBalance):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, HistoricalBalance):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class InflowModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'type': 'str',
        'income_amount': 'float',
        'payment_day_of_month': 'float',
        'transaction_name': 'str',
        'statement_day_of_month': 'str'
    }

    attribute_map = {
        'type': 'type',
        'income_amount': 'income_amount',
        'payment_day_of_month': 'payment_day_of_month',
        'transaction_name': 'transaction_name',
        'statement_day_of_month': 'statement_day_of_month'
    }

    def __init__(self, type=None, income_amount=None, payment_day_of_month=None, transaction_name=None, statement_day_of_month=None, local_vars_configuration=None):  # noqa: E501
        """InflowModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._type = None
        self._income_amount = None
        self._payment_day_of_month = None
        self._transaction_name = None
        self._statement_day_of_month = None
        self.discriminator = None

        self.type = type
        if income_amount is not None:
            self.income_amount = income_amount
        if payment_day_of_month is not None:
            self.payment_day_of_month = payment_day_of_month
        if transaction_name is not None:
            self.transaction_name = transaction_name
        if statement_day_of_month is not None:
            self.statement_day_of_month = statement_day_of_month

    @property
    def type(self):
        """Gets the type of this InflowModel.  # noqa: E501

        Inflow model. One of the following:  `none`: No income `monthly-income`: Income occurs once per month `monthly-balance-payment`: Pays off the balance on a liability account at the given statement day of month `monthly-interest-only-payment`: Makes an interest-only payment on a liability account at the given statement day of month. Note that account types supported by Liabilities will accrue interest in the Sandbox. The types are account type `credit` with subtype `credit` or `paypal`, and account type `loan` with subtype `student` or `mortgage`.  # noqa: E501

        :return: The type of this InflowModel.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this InflowModel.

        Inflow model. One of the following:  `none`: No income `monthly-income`: Income occurs once per month `monthly-balance-payment`: Pays off the balance on a liability account at the given statement day of month `monthly-interest-only-payment`: Makes an interest-only payment on a liability account at the given statement day of month. Note that account types supported by Liabilities will accrue interest in the Sandbox. The types are account type `credit` with subtype `credit` or `paypal`, and account type `loan` with subtype `student` or `mortgage`.  # noqa: E501

        :param type: The type of this InflowModel.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    @property
    def income_amount(self):
        """Gets the income_amount of this InflowModel.  # noqa: E501

        Amount of income per month. This value is required if `type` is `monthly-income`.  # noqa: E501

        :return: The income_amount of this InflowModel.  # noqa: E501
        :rtype: float
        """
        return self._income_amount

    @income_amount.setter
    def income_amount(self, income_amount):
        """Sets the income_amount of this InflowModel.

        Amount of income per month. This value is required if `type` is `monthly-income`.  # noqa: E501

        :param income_amount: The income_amount of this InflowModel.  # noqa: E501
        :type income_amount: float
        """

        self._income_amount = income_amount

    @property
    def payment_day_of_month(self):
        """Gets the payment_day_of_month of this InflowModel.  # noqa: E501

        Number between 1 and 28, or `last` meaning the last day of the month. The day of the month on which the income transaction will appear. The name of the income transaction. This field is required if `type` is `monthly-income`, `monthly-balance-payment` or `monthly-interest-only-payment`.  # noqa: E501

        :return: The payment_day_of_month of this InflowModel.  # noqa: E501
        :rtype: float
        """
        return self._payment_day_of_month

    @payment_day_of_month.setter
    def payment_day_of_month(self, payment_day_of_month):
        """Sets the payment_day_of_month of this InflowModel.

        Number between 1 and 28, or `last` meaning the last day of the month. The day of the month on which the income transaction will appear. The name of the income transaction. This field is required if `type` is `monthly-income`, `monthly-balance-payment` or `monthly-interest-only-payment`.  # noqa: E501

        :param payment_day_of_month: The payment_day_of_month of this InflowModel.  # noqa: E501
        :type payment_day_of_month: float
        """

        self._payment_day_of_month = payment_day_of_month

    @property
    def transaction_name(self):
        """Gets the transaction_name of this InflowModel.  # noqa: E501

        The name of the income transaction. This field is required if `type` is `monthly-income`, `monthly-balance-payment` or `monthly-interest-only-payment`.  # noqa: E501

        :return: The transaction_name of this InflowModel.  # noqa: E501
        :rtype: str
        """
        return self._transaction_name

    @transaction_name.setter
    def transaction_name(self, transaction_name):
        """Sets the transaction_name of this InflowModel.

        The name of the income transaction. This field is required if `type` is `monthly-income`, `monthly-balance-payment` or `monthly-interest-only-payment`.  # noqa: E501

        :param transaction_name: The transaction_name of this InflowModel.  # noqa: E501
        :type transaction_name: str
        """

        self._transaction_name = transaction_name

    @property
    def statement_day_of_month(self):
        """Gets the statement_day_of_month of this InflowModel.  # noqa: E501

        Number between 1 and 28, or `last` meaning the last day of the month. The day of the month on which the balance is calculated for the next payment. The name of the income transaction. This field is required if `type` is `monthly-balance-payment` or `monthly-interest-only-payment`.  # noqa: E501

        :return: The statement_day_of_month of this InflowModel.  # noqa: E501
        :rtype: str
        """
        return self._statement_day_of_month

    @statement_day_of_month.setter
    def statement_day_of_month(self, statement_day_of_month):
        """Sets the statement_day_of_month of this InflowModel.

        Number between 1 and 28, or `last` meaning the last day of the month. The day of the month on which the balance is calculated for the next payment. The name of the income transaction. This field is required if `type` is `monthly-balance-payment` or `monthly-interest-only-payment`.  # noqa: E501

        :param statement_day_of_month: The statement_day_of_month of this InflowModel.  # noqa: E501
        :type statement_day_of_month: str
        """

        self._statement_day_of_month = statement_day_of_month

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InflowModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InflowModel):
            return True

        return self.to_dict() != other.to_dict()



import plaid.generated_plaid as generated_plaid
from plaid.errors import PlaidError
from plaid.version import __version__

DEFAULT_TIMEOUT = 600  # 10 minutes
API_VERSION = "2020-09-14"


class Client:
    """
    Python Plaid API client.

    See official documentation at: https://plaid.com/docs.

    """

    def __init__(self, client_id=None, secret=None, environment=None, client_app=None):
        """
        Initialize a client with credentials.

        :param  str     client_id:          Your Plaid client ID
        :arg    str     secret:             Your Plaid secret
        :arg    str     environment:        One of ``sandbox``,
                                            ``development``, or ``production``.
        :arg    str     client_app:         Internal header to include
                                                in requests
        """
        self.client_id = client_id
        self.secret = secret
        self.environment = environment
        self.client_app = client_app
        self.api_version = API_VERSION
        if self.environment == "development":
            warnings.warn(
                """
                Development is not intended for production usage.
                Swap out url for https://production.plaid.com
                via Client.config before switching to production
            """
            )

        # initializing the generated client
        configuration = generated_plaid.Configuration(
            host=f"https://{self.environment}.plaid.com",
        )
        self.generated_client = generated_plaid.ApiClient(configuration)
        self.generated_api = generated_plaid.PlaidApi(self.generated_client)

        # configuring the generated client with headers
        self.generated_client.default_headers = {
            "Plaid-Version": self.api_version,
            "User-Agent": f"Plaid Python v{__version__}",
        }
        if self.client_app:
            self.generated_client.default_headers["Plaid-Client-App"] = self.client_app

        self.Accounts = Accounts(self)
        self.AssetReport = AssetReport(self)
        self.Auth = Auth(self)
        self.BankTransfer = BankTransfer(self)
        self.Categories = Categories(self)
        self.DepositSwitch = DepositSwitch(self)
        self.Holdings = Holdings(self)
        self.Identity = Identity(self)
        self.Institutions = Institutions(self)
        self.InvestmentTransactions = InvestmentTransactions(self)
        self.Item = Item(self)
        self.Liabilities = Liabilities(self)
        self.LinkToken = LinkToken(self)
        self.PaymentInitiation = PaymentInitiation(self)
        self.Processor = Processor(self)
        self.Sandbox = Sandbox(self)
        self.Transactions = Transactions(self)
        self.Webhooks = Webhooks(self)

    def handle_request(self, method, request):
        try:
            response = method(request)
            return response.to_dict()
        except Exception as e:
            raise PlaidError.from_generated_error(e)


class API:
    """Base class for classes containing groups of API endpoints."""

    def __init__(self, client: Client):
        self.client = client
        self.client_id = self.client.client_id
        self.secret = self.client.secret
        self.gen_api = self.client.generated_api


class Accounts(API):
    """
    Accounts endpoints.

    """

    def __init__(self, client):
        super(Accounts, self).__init__(client)
        self.balance = Accounts.Balance(client)

    def get(self, access_token, _options=None, account_ids=None):
        options = _options if _options else {}
        if account_ids is not None:
            options["account_ids"] = account_ids

        options = (
            generated_plaid.AccountsGetRequestOptions(**options) if options else None
        )

        request = generated_plaid.AccountsGetRequest(
            self.client_id,
            self.secret,
            access_token,
            options,
        )
        return self.client.handle_request(self.gen_api.accounts_get, request)

    class Balance(API):
        """Accounts balance endpoint."""

        def get(self, access_token, _options=None, account_ids=None):
            options = _options if _options else {}
            if account_ids is not None:
                options["account_ids"] = account_ids

            options = (
                generated_plaid.BalanceGetRequestOptions(**options) if options else None
            )

            request = generated_plaid.BalanceGetRequest(
                access_token,
                self.secret,
                self.client_id,
                options,
            )
            return self.client.handle_request(
                self.gen_api.balance_get,
                request,
            )


class AssetReport(API):
    """Assets endpoints."""

    def __init__(self, client: Client):
        super(AssetReport, self).__init__(client)
        self.audit_copy = AssetReport.AuditCopy(client)

    def create(self, access_tokens, days_requested, options=None):
        request = generated_plaid.AssetReportCreateRequest(
            self.client_id,
            self.secret,
            access_tokens,
            days_requested,
            options,
        )
        return self.client.handle_request(
            self.gen_api.asset_report_create,
            request,
        )

    def filter(self, asset_report_token, account_ids_to_exclude):
        request = generated_plaid.AssetReportFilterRequest(
            self.client_id,
            self.secret,
            asset_report_token,
            account_ids_to_exclude,
        )
        return self.client.handle_request(
            self.gen_api.asset_report_filter,
            request,
        )

    def refresh(self, asset_report_token, days_requested, options=None):
        request = generated_plaid.AssetReportRefreshRequest(
            self.client_id,
            self.secret,
            asset_report_token,
            days_requested,
            options,
        )
        return self.client.handle_request(
            self.gen_api.asset_report_refresh,
            request,
        )

    def get(self, asset_report_token, include_insights=False):
        request = generated_plaid.AssetReportGetRequest(
            self.client_id,
            self.secret,
            asset_report_token,
            include_insights,
        )
        return self.client.handle_request(
            self.gen_api.asset_report_get,
            request,
        )

    def get_pdf(self, asset_report_token):
        request = generated_plaid.AssetReportPDFGetRequest(
            self.client_id, self.secret, asset_report_token
        )
        temp_pdf_path = self.gen_api.asset_report_pdf_get(request)
        temp_pdf_fd = open(temp_pdf_path, "rb")
        contents = temp_pdf_fd.read()
        temp_pdf_fd.close()
        return contents

    def remove(self, asset_report_token):
        request = generated_plaid.AssetReportRemoveRequest(
            self.client_id,
            self.secret,
            asset_report_token,
        )
        return self.client.handle_request(
            self.gen_api.asset_report_remove,
            request,
        )

    class AuditCopy(API):
        """Audit copy endpoints. Use this class via the `audit_copy` member on
        the `AssetReport` class."""

        def create(self, asset_report_token, auditor_id):
            request = generated_plaid.AssetReportAuditCopyCreateRequest(
                self.client_id,
                self.secret,
                asset_report_token,
                auditor_id,
            )
            return self.client.handle_request(
                self.gen_api.asset_report_audit_copy_create,
                request,
            )

        def get(self, audit_copy_token):
            request = generated_plaid.AssetReportAuditCopyGetRequest(
                self.client_id,
                self.secret,
                audit_copy_token,
            )

            return self.client.handle_request(
                self.gen_api.asset_report_audit_copy_get,
                request,
            )

        def remove(self, audit_copy_token):
            request = generated_plaid.AssetReportAuditCopyRemoveRequest(
                self.client_id,
                self.secret,
                audit_copy_token,
            )
            return self.client.handle_request(
                self.gen_api.asset_report_audit_copy_remove,
                request,
            )


class Auth(API):
    """Auth endpoints."""

    def get(self, access_token, _options=None, account_ids=None):
        options = _options if _options else {}
        if account_ids is not None:
            options["account_ids"] = account_ids

        options = generated_plaid.AuthGetRequestOptions(**options) if options else None

        request = generated_plaid.AuthGetRequest(
            self.client_id,
            self.secret,
            access_token,
            options,
        )
        return self.client.handle_request(
            self.gen_api.auth_get,
            request,
        )


class BankTransfer(API):
    def __init__(self, client: Client):
        super(BankTransfer, self).__init__(client)
        self.balance = BankTransfer.Balance(client)

    def cancel(self, bank_transfer_id):
        request = generated_plaid.BankTransferCancelRequest(
            self.client_id,
            self.secret,
            bank_transfer_id,
        )

        return self.client.handle_request(
            self.gen_api.bank_transfer_cancel,
            request,
        )

    def create(
        self,
        idempotency_key,
        access_token,
        account_id,
        type,
        network,
        amount,
        iso_currency_code,
        description,
        user,
        metadata,
        ach_class=None,
        custom_tag=None,
        origination_account_id=None,
    ):
        request = generated_plaid.BankTransferCreateRequest(
            self.client_id,
            self.secret,
            idempotency_key,
            access_token,
            account_id,
            type,
            network,
            amount,
            iso_currency_code,
            description,
            ach_class,
            user,
            custom_tag,
            metadata,
            origination_account_id,
        )

        return self.client.handle_request(
            self.gen_api.bank_transfer_create,
            request,
        )

    def list_events(
        self,
        start_date=None,
        end_date=None,
        bank_transfer_id=None,
        account_id=None,
        bank_transfer_type=None,
        event_types=None,
        count=None,
        offset=None,
        origination_account_id=None,
        direction=None,
    ):

        request = generated_plaid.BankTransferEventListRequest(
            self.client_id,
            self.secret,
            start_date,
            end_date,
            bank_transfer_id,
            account_id,
            bank_transfer_type,
            event_types,
            count,
            offset,
            origination_account_id,
            direction,
        )

        return self.client.handle_request(
            self.gen_api.bank_transfer_event_list,
            request,
        )

    def sync_events(self, after_id, count=None):

        request = generated_plaid.BankTransferEventSyncRequest(
            self.client_id,
            self.secret,
            after_id,
            count,
        )

        return self.client.handle_request(
            self.gen_api.bank_transfer_event_sync,
            request,
        )

    def get(self, bank_transfer_id):
        request = generated_plaid.BankTransferGetRequest(
            self.client_id,
            self.secret,
            bank_transfer_id,
        )

        return self.client.handle_request(
            self.gen_api.bank_transfer_get,
            request,
        )

    def list(
        self,
        start_date=None,
        end_date=None,
        count=None,
        offset=None,
        origination_account_id=None,
        direction=None,
    ):

        request = generated_plaid.BankTransferListRequest(
            self.client_id,
            self.secret,
            start_date,
            end_date,
            count,
            offset,
            origination_account_id,
            direction,
        )

        return self.client.handle_request(
            self.gen_api.bank_transfer_list,
            request,
        )

    def migrate_account(
        self,
        account_number,
        routing_number,
        account_type,
    ):

        request = generated_plaid.BankTransferMigrateAccountRequest(
            self.client_id,
            self.secret,
            account_number,
            routing_number,
            account_type,
        )

        return self.client.handle_request(
            self.gen_api.bank_transfer_migrate_account,
            request,
        )

    class Balance(API):
        def get(self, origination_account_id=None):
            request = generated_plaid.BankTransferBalanceGetRequest(
                self.client_id, self.secret, origination_account_id
            )

            return self.client.handle_request(
                self.gen_api.bank_transfer_balance_get,
                request,
            )


class Categories(API):
    """
    Categories endpoints.
    """

    def get(self):
        request = {}
        return self.client.handle_request(self.gen_api.categories_get, request)


class DepositSwitch(API):
    """
    Deposit Switch endpoints.
    """

    def get(self, deposit_switch_id):
        request = generated_plaid.DepositSwitchGetRequest(
            self.client_id,
            self.secret,
            deposit_switch_id,
        )

        return self.client.handle_request(
            self.gen_api.deposit_switch_get,
            request,
        )

    def create(self, target_account_id, target_access_token):
        request = generated_plaid.DepositSwitchCreateRequest(
            self.client_id,
            self.secret,
            target_access_token,
            target_account_id,
        )

        return self.client.handle_request(
            self.gen_api.deposit_switch_create,
            request,
        )

    def create_token(self, deposit_switch_id):
        request = generated_plaid.DepositSwitchTokenCreateRequest(
            self.client_id,
            self.secret,
            deposit_switch_id,
        )

        return self.client.handle_request(
            self.gen_api.deposit_switch_token_create,
            request,
        )


class Holdings(API):
    """
    Holdings endpoints.
    """

    def get(self, access_token, _options=None, account_ids=None):
        options = _options if _options else {}
        if account_ids is not None:
            options["account_ids"] = account_ids

        options = (
            generated_plaid.InvestmentsHoldingsGetRequestOptions(**options)
            if options
            else None
        )

        request = generated_plaid.InvestmentsHoldingsGetRequest(
            self.client_id,
            self.secret,
            access_token,
            options,
        )
        return self.client.handle_request(
            self.gen_api.investments_holdings_get,
            request,
        )


class Identity(API):
    """
    Identity endpoints.
    """

    def get(self, access_token):
        request = generated_plaid.IdentityGetRequest(
            self.client_id,
            self.secret,
            access_token,
        )
        return self.client.handle_request(
            self.gen_api.identity_get,
            request,
        )


class Institutions(API):
    """
    Institutions endpoints.
    """

    def get(
        self,
        country_codes,
        count,
        offset=0,
        _options=None,
        products=None,
        routing_numbers=None,
        oauth=None,
        include_optional_metadata=None,
    ):
        options = _options if _options else {}
        if products is not None:
            options["products"] = products
        if routing_numbers is not None:
            options["routing_numbers"] = routing_numbers
        if oauth is not None:
            options["oauth"] = oauth
        if include_optional_metadata is not None:
            options["include_optional_metadata"] = include_optional_metadata

        options = (
            generated_plaid.InstitutionsGetRequestOptions(**options)
            if options
            else None
        )

        request = generated_plaid.InstitutionsGetRequest(
            self.client_id,
            self.secret,
            count,
            offset,
            country_codes,
            options,
        )

        return self.client.handle_request(
            self.gen_api.institutions_get,
            request,
        )

    def get_by_id(
        self,
        institution_id,
        country_codes,
        _options=None,
        include_optional_metadata=None,
        include_status=None,
    ):
        options = _options or {}
        if include_optional_metadata is not None:
            options["include_optional_metadata"] = include_optional_metadata
        if include_status is not None:
            options["include_status"] = include_status

        options = (
            generated_plaid.InstitutionsGetByIdRequestOptions(**options)
            if options
            else None
        )

        request = generated_plaid.InstitutionsGetByIdRequest(
            self.client_id,
            self.secret,
            institution_id,
            country_codes,
            options,
        )

        return self.client.handle_request(
            self.gen_api.institutions_get_by_id,
            request,
        )

    def search(
        self,
        query,
        products,
        country_codes,
        _options=None,
        oauth=None,
        include_optional_metadata=None,
    ):
        options = _options if _options else {}
        if oauth is not None:
            options["oauth"] = oauth
        if include_optional_metadata is not None:
            options["include_optional_metadata"] = include_optional_metadata

        options = (
            generated_plaid.InstitutionsSearchRequestOptions(**options)
            if options
            else None
        )

        request = generated_plaid.InstitutionSearchRequest(
            self.client_id,
            self.secret,
            query,
            products,
            country_codes,
            options,
        )

        return self.client.handle_request(
            self.gen_api.institutions_search,
            request,
        )


class Item(API):
    """
    Item endpoints.

    """

    def __init__(self, client):
        super(Item, self).__init__(client)
        self.access_token = Item.AccessToken(client)
        self.public_token = Item.PublicToken(client)
        self.webhook = Item.Webhook(client)

    def get(self, access_token):
        request = generated_plaid.ItemGetRequest(
            self.client_id,
            self.secret,
            access_token,
        )
        return self.client.handle_request(
            self.gen_api.item_get,
            request,
        )

    def remove(self, access_token):
        request = generated_plaid.ItemRemoveRequest(
            self.client_id,
            self.secret,
            access_token,
        )
        return self.client.handle_request(
            self.gen_api.item_remove,
            request,
        )

    def import_item(self, products, user_auth, _options=None, webhook=None):
        options = _options if _options else {}
        if webhook is not None:
            options["webhook"] = webhook

        options = (
            generated_plaid.ItemImportRequestOptions(**options) if options else None
        )

        request = generated_plaid.ItemImportRequest(
            self.client_id,
            self.secret,
            products,
            user_auth,
            options,
        )
        return self.client.handle_request(
            self.gen_api.item_import,
            request,
        )

    class PublicToken(API):
        def exchange(self, public_token):
            request = generated_plaid.ItemPublicTokenExchangeRequest(
                self.client_id,
                self.secret,
                public_token,
            )
            return self.client.handle_request(
                self.gen_api.item_public_token_exchange,
                request,
            )

    class AccessToken(API):
        def invalidate(self, access_token):
            request = generated_plaid.ItemAccessTokenInvalidateRequest(
                self.client_id,
                self.secret,
                access_token,
            )
            return self.client.handle_request(
                self.gen_api.item_access_token_invalidate,
                request,
            )

    class Webhook(API):
        def update(self, access_token, webhook):
            request = generated_plaid.ItemWebhookUpdateRequest(
                self.client_id,
                self.secret,
                access_token,
                webhook,
            )
            return self.client.handle_request(
                self.gen_api.item_webhook_update,
                request,
            )


class InvestmentTransactions(API):
    """InvestmentTransactions endpoints."""

    def get(
        self,
        access_token,
        start_date,
        end_date,
        _options=None,
        account_ids=None,
        count=None,
        offset=None,
    ):
        options = _options if _options else {}
        if account_ids is not None:
            options["account_ids"] = account_ids
        if count is not None:
            options["count"] = count
        if offset is not None:
            options["offset"] = offset

        options = (
            generated_plaid.InvestmentsTransactionsGetRequestOptions(**options)
            if options
            else None
        )

        request = generated_plaid.InvestmentsTransactionsGetRequest(
            self.client_id,
            self.secret,
            access_token,
            start_date,
            end_date,
            options,
        )

        return self.client.handle_request(
            self.gen_api.investments_transactions_get,
            request,
        )


class Liabilities(API):
    """
    Liabilities endpoints.
    """

    def get(self, access_token, _options=None, account_ids=None):
        options = _options if _options else {}
        if account_ids is not None:
            options["account_ids"] = account_ids

        options = (
            generated_plaid.LiabilitiesGetRequestOptions(**options) if options else None
        )

        request = generated_plaid.LiabilitiesGetRequest(
            self.client_id, self.secret, access_token, options
        )

        return self.client.handle_request(
            self.gen_api.liabilities_get,
            request,
        )


class LinkToken(API):
    """Endpoints for managing link tokens."""

    def create(self, configs):
        configs["client_id"] = self.client_id
        configs["secret"] = self.secret
        request = generated_plaid.LinkTokenCreateRequest(**configs)

        return self.client.handle_request(
            self.gen_api.link_token_create,
            request,
        )

    def get(self, link_token):
        request = generated_plaid.LinkTokenGetRequest(
            self.client_id,
            self.secret,
            link_token,
        )

        return self.client.handle_request(
            self.gen_api.link_token_get,
            request,
        )


class PaymentInitiation(API):
    """Payment Initiation endpoints."""

    def create_recipient(self, name, iban, address, bacs):
        address = (
            generated_plaid.PaymentInitiationAddress(**address) if address else None
        )
        if bacs:
            bacs = generated_plaid.PaymentInitiationRecipientGetResponseBacs(
                bacs.get("account"),
                bacs.get("sort_code"),
            )
        request = generated_plaid.PaymentInitiationRecipientCreateRequest(
            self.client_id,
            self.secret,
            name,
            iban,
            bacs,
            address,
        )

        return self.client.handle_request(
            self.gen_api.payment_initiation_recipient_create,
            request,
        )

    def get_recipient(self, recipient_id):
        request = generated_plaid.PaymentInitiationRecipientGetRequest(
            self.client_id,
            self.secret,
            recipient_id,
        )

        return self.client.handle_request(
            self.gen_api.payment_initiation_recipient_get,
            request,
        )

    def list_recipients(self):
        request = generated_plaid.PaymentInitiationRecipientListRequest(
            self.client_id,
            self.secret,
        )

        return self.client.handle_request(
            self.gen_api.payment_initiation_recipient_list,
            request,
        )

    def create_payment(self, recipient_id, reference, amount, schedule=None):
        request = generated_plaid.PaymentInitiationPaymentCreateRequest(
            self.client_id,
            self.secret,
            recipient_id,
            reference,
            amount,
            schedule,
        )

        return self.client.handle_request(
            self.gen_api.payment_initiation_payment_create,
            request,
        )

    def get_payment(self, payment_id):
        request = generated_plaid.PaymentIntiationPaymentGetRequest(
            self.client_id,
            self.secret,
            payment_id,
        )

        return self.client.handle_request(
            self.gen_api.payment_intiation_payment_get,
            request,
        )

    def list_payments(self, count=None, cursor=None):
        request = generated_plaid.PaymentInitiationPaymentListRequest(
            self.client_id,
            self.secret,
            count,
            cursor,
        )

        return self.client.handle_request(
            self.gen_api.payment_initiation_payment_list, request
        )


class Processor(API):
    """Endpoints for creating processor tokens."""

    def token_create(self, access_token, account_id, processor):
        if processor == "stripe":
            return self.stripe_bank_account_token_create(access_token, account_id)
        elif processor == "apex":
            return self.apex_bank_account_token_create(access_token, account_id)
        else:
            request = generated_plaid.ProcessorTokenCreateRequest(
                self.client_id,
                self.secret,
                access_token,
                account_id,
                processor,
            )

            return self.client.handle_request(
                self.gen_api.processor_token_create, request
            )

    def stripe_bank_account_token_create(self, access_token, account_id):
        request = generated_plaid.ProcessorStripeBankAccountTokenCreateRequest(
            self.client_id,
            self.secret,
            access_token,
            account_id,
        )

        return self.client.handle_request(
            self.gen_api.processor_stripe_bank_account_token_create,
            request,
        )

    def dwolla_bank_account_token_create(self, access_token, account_id):
        return self.token_create(access_token, account_id, "dwolla")

    def apex_bank_account_token_create(self, access_token, account_id):
        request = generated_plaid.ProcessorApexProcessorTokenCreateRequest(
            self.client_id,
            self.secret,
            access_token,
            account_id,
        )

        return self.client.handle_request(
            self.gen_api.processor_apex_processor_token_create,
            request,
        )

    def auth_get(self, processor_token):
        request = generated_plaid.ProcessorAuthGetRequest(
            self.client_id,
            self.secret,
            processor_token,
        )

        return self.client.handle_request(
            self.gen_api.processor_auth_get,
            request,
        )

    def balance_get(self, processor_token):
        request = generated_plaid.ProcessorBalanceGetRequest(
            self.client_id,
            self.secret,
            processor_token,
        )

        return self.client.handle_request(
            self.gen_api.processor_balance_get,
            request,
        )

    def identity_get(self, processor_token):
        request = generated_plaid.ProcessorIdentityGetRequest(
            self.client_id,
            self.secret,
            processor_token,
        )

        return self.client.handle_request(
            self.gen_api.processor_identity_get,
            request,
        )


class Sandbox(API):
    """
    Sandbox-only endpoints.

    These endpoints may not be used in other environments.

    """

    def __init__(self, client: Client):
        super(Sandbox, self).__init__(client)
        self.bank_transfer = Sandbox.BankTransfer(client)
        self.item = Sandbox.Item(client)
        self.public_token = Sandbox.PublicToken(client)

    class BankTransfer(API):
        def simulate(self, bank_transfer_id, event_type, failure_reason=None):
            request = generated_plaid.SandboxBankTransferSimulateRequest(
                self.client_id,
                self.secret,
                bank_transfer_id,
                event_type,
                failure_reason,
            )

            return self.client.handle_request(
                self.gen_api.sandbox_bank_transfer_simulate,
                request,
            )

    class Item(API):
        """Sandbox item endpoints."""

        def reset_login(self, access_token):
            request = generated_plaid.SandboxItemResetLoginRequest(
                self.client_id,
                self.secret,
                access_token,
            )
            return self.client.handle_request(
                self.gen_api.sandbox_item_reset_login,
                request,
            )

        def fire_webhook(self, access_token, webhook_code):
            request = generated_plaid.SandboxItemFireWebhookRequest(
                self.client_id,
                self.secret,
                access_token,
                webhook_code,
            )
            return self.client.handle_request(
                self.gen_api.sandbox_item_fire_webhook,
                request,
            )

        def set_verification_status(
            self, access_token, account_id, verification_status
        ):
            request = generated_plaid.SandboxItemSetVerificationStatusRequest(
                self.client_id,
                self.secret,
                access_token,
                account_id,
                verification_status,
            )
            return self.client.handle_request(
                self.gen_api.sandbox_item_set_verification_status,
                request,
            )

    class PublicToken(API):
        """Sandbox public token endpoints."""

        def create(
            self,
            institution_id,
            initial_products,
            _options=None,
            webhook=None,
            override_username="user_good",
            override_password="pass_good",
            transactions__start_date=None,
            transactions__end_date=None,
        ):
            options = _options if _options else {}
            if webhook is not None:
                options["webhook"] = webhook
            if override_username is not None:
                options["override_username"] = override_username
            if override_password is not None:
                options["override_password"] = override_password
            if (
                transactions__start_date is not None
                or transactions__end_date is not None
            ):
                transactions = (
                    generated_plaid.SandboxPublicTokenCreateRequestOptionsTransactions(
                        transactions__start_date,
                        transactions__end_date,
                    )
                )
                options["transactions"] = transactions

            options = (
                generated_plaid.SandboxPublicTokenCreateRequestOptions(**options)
                if options
                else None
            )

            request = generated_plaid.SandboxPublicTokenCreateRequest(
                self.client_id,
                self.secret,
                institution_id,
                initial_products,
                options,
            )
            return self.client.handle_request(
                self.gen_api.sandbox_public_token_create,
                request,
            )


class Transactions(API):
    """Transactions endpoints."""

    def get(
        self,
        access_token,
        start_date,
        end_date,
        _options=None,
        account_ids=None,
        count=None,
        offset=None,
    ):
        options = _options if _options else {}
        if account_ids is not None:
            options["account_ids"] = account_ids if account_ids else None
        if count is not None:
            options["count"] = count
        if offset is not None:
            options["offset"] = offset

        options = (
            generated_plaid.TransactionsGetRequestOptions(**options)
            if options
            else None
        )

        request = generated_plaid.TransactionsGetRequest(
            self.client_id,
            options,
            access_token,
            self.secret,
            start_date,
            end_date,
        )

        return self.client.handle_request(
            self.gen_api.transactions_get,
            request,
        )

    def refresh(self, access_token):
        request = generated_plaid.TransactionsRefreshRequest(
            self.client_id,
            access_token,
            self.secret,
        )

        return self.client.handle_request(
            self.gen_api.transactions_refresh,
            request,
        )


class Webhooks(API):
    """
    Webhooks endpoints.
    """

    def get_verification_key(self, key_id):
        request = generated_plaid.WebhookVerificationKeyGetRequest(
            self.client_id,
            self.secret,
            key_id,
        )

        return self.client.handle_request(
            self.gen_api.webhook_verification_key_get,
            request,
        )



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class InstitutionsGetByIdRequestOptions(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'include_optional_metadata': 'bool',
        'include_status': 'bool'
    }

    attribute_map = {
        'include_optional_metadata': 'include_optional_metadata',
        'include_status': 'include_status'
    }

    def __init__(self, include_optional_metadata=False, include_status=False, local_vars_configuration=None):  # noqa: E501
        """InstitutionsGetByIdRequestOptions - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._include_optional_metadata = None
        self._include_status = None
        self.discriminator = None

        if include_optional_metadata is not None:
            self.include_optional_metadata = include_optional_metadata
        if include_status is not None:
            self.include_status = include_status

    @property
    def include_optional_metadata(self):
        """Gets the include_optional_metadata of this InstitutionsGetByIdRequestOptions.  # noqa: E501

        When `true`, return an institution's logo, brand color, and URL. When available, the bank's logo is returned as a base64 encoded 152x152 PNG, the brand color is in hexadecimal format. The default value is `false`.  Note that Plaid does not own any of the logos shared by the API and that by accessing or using these logos, you agree that you are doing so at your own risk and will, if necessary, obtain all required permissions from the appropriate rights holders and adhere to any applicable usage guidelines. Plaid disclaims all express or implied warranties with respect to the logos.  # noqa: E501

        :return: The include_optional_metadata of this InstitutionsGetByIdRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_optional_metadata

    @include_optional_metadata.setter
    def include_optional_metadata(self, include_optional_metadata):
        """Sets the include_optional_metadata of this InstitutionsGetByIdRequestOptions.

        When `true`, return an institution's logo, brand color, and URL. When available, the bank's logo is returned as a base64 encoded 152x152 PNG, the brand color is in hexadecimal format. The default value is `false`.  Note that Plaid does not own any of the logos shared by the API and that by accessing or using these logos, you agree that you are doing so at your own risk and will, if necessary, obtain all required permissions from the appropriate rights holders and adhere to any applicable usage guidelines. Plaid disclaims all express or implied warranties with respect to the logos.  # noqa: E501

        :param include_optional_metadata: The include_optional_metadata of this InstitutionsGetByIdRequestOptions.  # noqa: E501
        :type include_optional_metadata: bool
        """

        self._include_optional_metadata = include_optional_metadata

    @property
    def include_status(self):
        """Gets the include_status of this InstitutionsGetByIdRequestOptions.  # noqa: E501

        If `true`, the response will include status information about the institution. Default value is `false`.  # noqa: E501

        :return: The include_status of this InstitutionsGetByIdRequestOptions.  # noqa: E501
        :rtype: bool
        """
        return self._include_status

    @include_status.setter
    def include_status(self, include_status):
        """Sets the include_status of this InstitutionsGetByIdRequestOptions.

        If `true`, the response will include status information about the institution. Default value is `false`.  # noqa: E501

        :param include_status: The include_status of this InstitutionsGetByIdRequestOptions.  # noqa: E501
        :type include_status: bool
        """

        self._include_status = include_status

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstitutionsGetByIdRequestOptions):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InstitutionsGetByIdRequestOptions):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Numbers(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'account': 'str',
        'ach_routing': 'str',
        'ach_wire_routing': 'str',
        'eft_institution': 'str',
        'eft_branch': 'str',
        'international_bic': 'str',
        'international_iban': 'str',
        'bacs_sort_code': 'str'
    }

    attribute_map = {
        'account': 'account',
        'ach_routing': 'ach_routing',
        'ach_wire_routing': 'ach_wire_routing',
        'eft_institution': 'eft_institution',
        'eft_branch': 'eft_branch',
        'international_bic': 'international_bic',
        'international_iban': 'international_iban',
        'bacs_sort_code': 'bacs_sort_code'
    }

    def __init__(self, account=None, ach_routing=None, ach_wire_routing=None, eft_institution=None, eft_branch=None, international_bic=None, international_iban=None, bacs_sort_code=None, local_vars_configuration=None):  # noqa: E501
        """Numbers - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._account = None
        self._ach_routing = None
        self._ach_wire_routing = None
        self._eft_institution = None
        self._eft_branch = None
        self._international_bic = None
        self._international_iban = None
        self._bacs_sort_code = None
        self.discriminator = None

        if account is not None:
            self.account = account
        if ach_routing is not None:
            self.ach_routing = ach_routing
        if ach_wire_routing is not None:
            self.ach_wire_routing = ach_wire_routing
        if eft_institution is not None:
            self.eft_institution = eft_institution
        if eft_branch is not None:
            self.eft_branch = eft_branch
        if international_bic is not None:
            self.international_bic = international_bic
        if international_iban is not None:
            self.international_iban = international_iban
        if bacs_sort_code is not None:
            self.bacs_sort_code = bacs_sort_code

    @property
    def account(self):
        """Gets the account of this Numbers.  # noqa: E501

        Will be used for the account number.  # noqa: E501

        :return: The account of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._account

    @account.setter
    def account(self, account):
        """Sets the account of this Numbers.

        Will be used for the account number.  # noqa: E501

        :param account: The account of this Numbers.  # noqa: E501
        :type account: str
        """

        self._account = account

    @property
    def ach_routing(self):
        """Gets the ach_routing of this Numbers.  # noqa: E501

        Must be a valid ACH routing number.  # noqa: E501

        :return: The ach_routing of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._ach_routing

    @ach_routing.setter
    def ach_routing(self, ach_routing):
        """Sets the ach_routing of this Numbers.

        Must be a valid ACH routing number.  # noqa: E501

        :param ach_routing: The ach_routing of this Numbers.  # noqa: E501
        :type ach_routing: str
        """

        self._ach_routing = ach_routing

    @property
    def ach_wire_routing(self):
        """Gets the ach_wire_routing of this Numbers.  # noqa: E501

        Must be a valid wire transfer routing number.  # noqa: E501

        :return: The ach_wire_routing of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._ach_wire_routing

    @ach_wire_routing.setter
    def ach_wire_routing(self, ach_wire_routing):
        """Sets the ach_wire_routing of this Numbers.

        Must be a valid wire transfer routing number.  # noqa: E501

        :param ach_wire_routing: The ach_wire_routing of this Numbers.  # noqa: E501
        :type ach_wire_routing: str
        """

        self._ach_wire_routing = ach_wire_routing

    @property
    def eft_institution(self):
        """Gets the eft_institution of this Numbers.  # noqa: E501

        EFT institution number. Must be specified alongside `eft_branch`.  # noqa: E501

        :return: The eft_institution of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._eft_institution

    @eft_institution.setter
    def eft_institution(self, eft_institution):
        """Sets the eft_institution of this Numbers.

        EFT institution number. Must be specified alongside `eft_branch`.  # noqa: E501

        :param eft_institution: The eft_institution of this Numbers.  # noqa: E501
        :type eft_institution: str
        """

        self._eft_institution = eft_institution

    @property
    def eft_branch(self):
        """Gets the eft_branch of this Numbers.  # noqa: E501

        EFT branch number. Must be specified alongside `eft_institution`.  # noqa: E501

        :return: The eft_branch of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._eft_branch

    @eft_branch.setter
    def eft_branch(self, eft_branch):
        """Sets the eft_branch of this Numbers.

        EFT branch number. Must be specified alongside `eft_institution`.  # noqa: E501

        :param eft_branch: The eft_branch of this Numbers.  # noqa: E501
        :type eft_branch: str
        """

        self._eft_branch = eft_branch

    @property
    def international_bic(self):
        """Gets the international_bic of this Numbers.  # noqa: E501

        Bank identifier code (BIC). Must be specified alongside `international_iban`.  # noqa: E501

        :return: The international_bic of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._international_bic

    @international_bic.setter
    def international_bic(self, international_bic):
        """Sets the international_bic of this Numbers.

        Bank identifier code (BIC). Must be specified alongside `international_iban`.  # noqa: E501

        :param international_bic: The international_bic of this Numbers.  # noqa: E501
        :type international_bic: str
        """

        self._international_bic = international_bic

    @property
    def international_iban(self):
        """Gets the international_iban of this Numbers.  # noqa: E501

        International bank account number (IBAN). If no account number is specified via `account`, will also be used as the account number by default. Must be specified alongside `international_bic`.  # noqa: E501

        :return: The international_iban of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._international_iban

    @international_iban.setter
    def international_iban(self, international_iban):
        """Sets the international_iban of this Numbers.

        International bank account number (IBAN). If no account number is specified via `account`, will also be used as the account number by default. Must be specified alongside `international_bic`.  # noqa: E501

        :param international_iban: The international_iban of this Numbers.  # noqa: E501
        :type international_iban: str
        """

        self._international_iban = international_iban

    @property
    def bacs_sort_code(self):
        """Gets the bacs_sort_code of this Numbers.  # noqa: E501

        BACS sort code  # noqa: E501

        :return: The bacs_sort_code of this Numbers.  # noqa: E501
        :rtype: str
        """
        return self._bacs_sort_code

    @bacs_sort_code.setter
    def bacs_sort_code(self, bacs_sort_code):
        """Sets the bacs_sort_code of this Numbers.

        BACS sort code  # noqa: E501

        :param bacs_sort_code: The bacs_sort_code of this Numbers.  # noqa: E501
        :type bacs_sort_code: str
        """

        self._bacs_sort_code = bacs_sort_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Numbers):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Numbers):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    The Plaid API

    The Plaid REST API. Please see https://plaid.com/docs/api for more details.  # noqa: E501

    The version of the OpenAPI document: 2020-09-14_1.0.11
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from plaid.generated_plaid.configuration import Configuration


class Transaction(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'transaction_type': 'str',
        'transaction_id': 'str',
        'account_owner': 'str',
        'pending_transaction_id': 'str',
        'pending': 'bool',
        'payment_channel': 'str',
        'payment_meta': 'PaymentMeta',
        'name': 'str',
        'merchant_name': 'str',
        'location': 'Location',
        'authorized_date': 'str',
        'date': 'str',
        'category_id': 'str',
        'category': 'list[str]',
        'unofficial_currency_code': 'str',
        'iso_currency_code': 'str',
        'amount': 'float',
        'account_id': 'str',
        'transaction_code': 'TransactionCode'
    }

    attribute_map = {
        'transaction_type': 'transaction_type',
        'transaction_id': 'transaction_id',
        'account_owner': 'account_owner',
        'pending_transaction_id': 'pending_transaction_id',
        'pending': 'pending',
        'payment_channel': 'payment_channel',
        'payment_meta': 'payment_meta',
        'name': 'name',
        'merchant_name': 'merchant_name',
        'location': 'location',
        'authorized_date': 'authorized_date',
        'date': 'date',
        'category_id': 'category_id',
        'category': 'category',
        'unofficial_currency_code': 'unofficial_currency_code',
        'iso_currency_code': 'iso_currency_code',
        'amount': 'amount',
        'account_id': 'account_id',
        'transaction_code': 'transaction_code'
    }

    def __init__(self, transaction_type=None, transaction_id=None, account_owner=None, pending_transaction_id=None, pending=None, payment_channel=None, payment_meta=None, name=None, merchant_name=None, location=None, authorized_date=None, date=None, category_id=None, category=None, unofficial_currency_code=None, iso_currency_code=None, amount=None, account_id=None, transaction_code=None, local_vars_configuration=None):  # noqa: E501
        """Transaction - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._transaction_type = None
        self._transaction_id = None
        self._account_owner = None
        self._pending_transaction_id = None
        self._pending = None
        self._payment_channel = None
        self._payment_meta = None
        self._name = None
        self._merchant_name = None
        self._location = None
        self._authorized_date = None
        self._date = None
        self._category_id = None
        self._category = None
        self._unofficial_currency_code = None
        self._iso_currency_code = None
        self._amount = None
        self._account_id = None
        self._transaction_code = None
        self.discriminator = None

        if transaction_type is not None:
            self.transaction_type = transaction_type
        if transaction_id is not None:
            self.transaction_id = transaction_id
        self.account_owner = account_owner
        self.pending_transaction_id = pending_transaction_id
        if pending is not None:
            self.pending = pending
        if payment_channel is not None:
            self.payment_channel = payment_channel
        if payment_meta is not None:
            self.payment_meta = payment_meta
        if name is not None:
            self.name = name
        self.merchant_name = merchant_name
        if location is not None:
            self.location = location
        self.authorized_date = authorized_date
        if date is not None:
            self.date = date
        if category_id is not None:
            self.category_id = category_id
        self.category = category
        self.unofficial_currency_code = unofficial_currency_code
        self.iso_currency_code = iso_currency_code
        if amount is not None:
            self.amount = amount
        if account_id is not None:
            self.account_id = account_id
        self.transaction_code = transaction_code

    @property
    def transaction_type(self):
        """Gets the transaction_type of this Transaction.  # noqa: E501

        Please use the `payment_channel` field, `transaction_type` will be deprecated in the future.  `digital:` transactions that took place online.  `place:` transactions that were made at a physical location.  `special:` transactions that relate to banks, e.g. fees or deposits.  `unresolved:` transactions that do not fit into the other three types.    # noqa: E501

        :return: The transaction_type of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """Sets the transaction_type of this Transaction.

        Please use the `payment_channel` field, `transaction_type` will be deprecated in the future.  `digital:` transactions that took place online.  `place:` transactions that were made at a physical location.  `special:` transactions that relate to banks, e.g. fees or deposits.  `unresolved:` transactions that do not fit into the other three types.    # noqa: E501

        :param transaction_type: The transaction_type of this Transaction.  # noqa: E501
        :type transaction_type: str
        """
        allowed_values = ["digital", "place", "special", "unresolved"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and transaction_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `transaction_type` ({0}), must be one of {1}"  # noqa: E501
                .format(transaction_type, allowed_values)
            )

        self._transaction_type = transaction_type

    @property
    def transaction_id(self):
        """Gets the transaction_id of this Transaction.  # noqa: E501

        The unique ID of the transaction. Like all Plaid identifiers, the `transaction_id` is case sensitive.  # noqa: E501

        :return: The transaction_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._transaction_id

    @transaction_id.setter
    def transaction_id(self, transaction_id):
        """Sets the transaction_id of this Transaction.

        The unique ID of the transaction. Like all Plaid identifiers, the `transaction_id` is case sensitive.  # noqa: E501

        :param transaction_id: The transaction_id of this Transaction.  # noqa: E501
        :type transaction_id: str
        """

        self._transaction_id = transaction_id

    @property
    def account_owner(self):
        """Gets the account_owner of this Transaction.  # noqa: E501

        The name of the account owner. This field is not typically populated and only relevant when dealing with sub-accounts.  # noqa: E501

        :return: The account_owner of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._account_owner

    @account_owner.setter
    def account_owner(self, account_owner):
        """Sets the account_owner of this Transaction.

        The name of the account owner. This field is not typically populated and only relevant when dealing with sub-accounts.  # noqa: E501

        :param account_owner: The account_owner of this Transaction.  # noqa: E501
        :type account_owner: str
        """

        self._account_owner = account_owner

    @property
    def pending_transaction_id(self):
        """Gets the pending_transaction_id of this Transaction.  # noqa: E501

        The ID of a posted transaction's associated pending transaction, where applicable.  # noqa: E501

        :return: The pending_transaction_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._pending_transaction_id

    @pending_transaction_id.setter
    def pending_transaction_id(self, pending_transaction_id):
        """Sets the pending_transaction_id of this Transaction.

        The ID of a posted transaction's associated pending transaction, where applicable.  # noqa: E501

        :param pending_transaction_id: The pending_transaction_id of this Transaction.  # noqa: E501
        :type pending_transaction_id: str
        """

        self._pending_transaction_id = pending_transaction_id

    @property
    def pending(self):
        """Gets the pending of this Transaction.  # noqa: E501

        When `true`, identifies the transaction as pending or unsettled. Pending transaction details (name, type, amount, category ID) may change before they are settled.  # noqa: E501

        :return: The pending of this Transaction.  # noqa: E501
        :rtype: bool
        """
        return self._pending

    @pending.setter
    def pending(self, pending):
        """Sets the pending of this Transaction.

        When `true`, identifies the transaction as pending or unsettled. Pending transaction details (name, type, amount, category ID) may change before they are settled.  # noqa: E501

        :param pending: The pending of this Transaction.  # noqa: E501
        :type pending: bool
        """

        self._pending = pending

    @property
    def payment_channel(self):
        """Gets the payment_channel of this Transaction.  # noqa: E501

        The channel used to make a payment.  `online:` transactions that took place online.  `in store:` transactions that were made at a physical location.  `other:` transactions that relate to banks, e.g. fees or deposits.  This field replaces the `transaction_type` field.   # noqa: E501

        :return: The payment_channel of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._payment_channel

    @payment_channel.setter
    def payment_channel(self, payment_channel):
        """Sets the payment_channel of this Transaction.

        The channel used to make a payment.  `online:` transactions that took place online.  `in store:` transactions that were made at a physical location.  `other:` transactions that relate to banks, e.g. fees or deposits.  This field replaces the `transaction_type` field.   # noqa: E501

        :param payment_channel: The payment_channel of this Transaction.  # noqa: E501
        :type payment_channel: str
        """
        allowed_values = ["online", "in store", "other"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and payment_channel not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `payment_channel` ({0}), must be one of {1}"  # noqa: E501
                .format(payment_channel, allowed_values)
            )

        self._payment_channel = payment_channel

    @property
    def payment_meta(self):
        """Gets the payment_meta of this Transaction.  # noqa: E501


        :return: The payment_meta of this Transaction.  # noqa: E501
        :rtype: PaymentMeta
        """
        return self._payment_meta

    @payment_meta.setter
    def payment_meta(self, payment_meta):
        """Sets the payment_meta of this Transaction.


        :param payment_meta: The payment_meta of this Transaction.  # noqa: E501
        :type payment_meta: PaymentMeta
        """

        self._payment_meta = payment_meta

    @property
    def name(self):
        """Gets the name of this Transaction.  # noqa: E501

        The merchant name or transaction description.   If the `transaction` object was returned by a Transactions endpoint such as `/transactions/get`, this field will always appear. If the `transaction` object was returned by an Assets endpoint such as `/asset_report/get/` or `/asset_report/pdf/get`, this field will only appear in an Asset Report with Insights.  # noqa: E501

        :return: The name of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Transaction.

        The merchant name or transaction description.   If the `transaction` object was returned by a Transactions endpoint such as `/transactions/get`, this field will always appear. If the `transaction` object was returned by an Assets endpoint such as `/asset_report/get/` or `/asset_report/pdf/get`, this field will only appear in an Asset Report with Insights.  # noqa: E501

        :param name: The name of this Transaction.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def merchant_name(self):
        """Gets the merchant_name of this Transaction.  # noqa: E501

        The merchant name, as extracted by Plaid from the `name` field.  # noqa: E501

        :return: The merchant_name of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, merchant_name):
        """Sets the merchant_name of this Transaction.

        The merchant name, as extracted by Plaid from the `name` field.  # noqa: E501

        :param merchant_name: The merchant_name of this Transaction.  # noqa: E501
        :type merchant_name: str
        """

        self._merchant_name = merchant_name

    @property
    def location(self):
        """Gets the location of this Transaction.  # noqa: E501


        :return: The location of this Transaction.  # noqa: E501
        :rtype: Location
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this Transaction.


        :param location: The location of this Transaction.  # noqa: E501
        :type location: Location
        """

        self._location = location

    @property
    def authorized_date(self):
        """Gets the authorized_date of this Transaction.  # noqa: E501

        The date that the transaction was authorized. Dates are returned in an ISO 8601 format ( `YYYY-MM-DD` ).  # noqa: E501

        :return: The authorized_date of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._authorized_date

    @authorized_date.setter
    def authorized_date(self, authorized_date):
        """Sets the authorized_date of this Transaction.

        The date that the transaction was authorized. Dates are returned in an ISO 8601 format ( `YYYY-MM-DD` ).  # noqa: E501

        :param authorized_date: The authorized_date of this Transaction.  # noqa: E501
        :type authorized_date: str
        """

        self._authorized_date = authorized_date

    @property
    def date(self):
        """Gets the date of this Transaction.  # noqa: E501

        For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted. Both dates are returned in an ISO 8601 format ( `YYYY-MM-DD` ).  # noqa: E501

        :return: The date of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._date

    @date.setter
    def date(self, date):
        """Sets the date of this Transaction.

        For pending transactions, the date that the transaction occurred; for posted transactions, the date that the transaction posted. Both dates are returned in an ISO 8601 format ( `YYYY-MM-DD` ).  # noqa: E501

        :param date: The date of this Transaction.  # noqa: E501
        :type date: str
        """

        self._date = date

    @property
    def category_id(self):
        """Gets the category_id of this Transaction.  # noqa: E501

        The ID of the category to which this transaction belongs. See [Categories](https://plaid.com/docs/#category-overview).   If the `transaction` object was returned by an Assets endpoint such as `/asset_report/get/` or `/asset_report/pdf/get`, this field will only appear in an Asset Report with Insights.  # noqa: E501

        :return: The category_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._category_id

    @category_id.setter
    def category_id(self, category_id):
        """Sets the category_id of this Transaction.

        The ID of the category to which this transaction belongs. See [Categories](https://plaid.com/docs/#category-overview).   If the `transaction` object was returned by an Assets endpoint such as `/asset_report/get/` or `/asset_report/pdf/get`, this field will only appear in an Asset Report with Insights.  # noqa: E501

        :param category_id: The category_id of this Transaction.  # noqa: E501
        :type category_id: str
        """

        self._category_id = category_id

    @property
    def category(self):
        """Gets the category of this Transaction.  # noqa: E501

        A hierarchical array of the categories to which this transaction belongs. See [Categories](https://plaid.com/docs/#category-overview).   If the `transaction` object was returned by an Assets endpoint such as `/asset_report/get/` or `/asset_report/pdf/get`, this field will only appear in an Asset Report with Insights.  # noqa: E501

        :return: The category of this Transaction.  # noqa: E501
        :rtype: list[str]
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this Transaction.

        A hierarchical array of the categories to which this transaction belongs. See [Categories](https://plaid.com/docs/#category-overview).   If the `transaction` object was returned by an Assets endpoint such as `/asset_report/get/` or `/asset_report/pdf/get`, this field will only appear in an Asset Report with Insights.  # noqa: E501

        :param category: The category of this Transaction.  # noqa: E501
        :type category: list[str]
        """

        self._category = category

    @property
    def unofficial_currency_code(self):
        """Gets the unofficial_currency_code of this Transaction.  # noqa: E501

        The unofficial currency code associated with the transaction. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :return: The unofficial_currency_code of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._unofficial_currency_code

    @unofficial_currency_code.setter
    def unofficial_currency_code(self, unofficial_currency_code):
        """Sets the unofficial_currency_code of this Transaction.

        The unofficial currency code associated with the transaction. Always `null` if `iso_currency_code` is non-`null`. Unofficial currency codes are used for currencies that do not have official ISO currency codes, such as cryptocurrencies and the currencies of certain countries.  See the [currency code schema](/docs/api/accounts#currency-code-schema) for a full listing of supported `iso_currency_code`s.  # noqa: E501

        :param unofficial_currency_code: The unofficial_currency_code of this Transaction.  # noqa: E501
        :type unofficial_currency_code: str
        """

        self._unofficial_currency_code = unofficial_currency_code

    @property
    def iso_currency_code(self):
        """Gets the iso_currency_code of this Transaction.  # noqa: E501

        The ISO-4217 currency code of the transaction. Always `null` if `unofficial_currency_code` is non-null.  # noqa: E501

        :return: The iso_currency_code of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._iso_currency_code

    @iso_currency_code.setter
    def iso_currency_code(self, iso_currency_code):
        """Sets the iso_currency_code of this Transaction.

        The ISO-4217 currency code of the transaction. Always `null` if `unofficial_currency_code` is non-null.  # noqa: E501

        :param iso_currency_code: The iso_currency_code of this Transaction.  # noqa: E501
        :type iso_currency_code: str
        """

        self._iso_currency_code = iso_currency_code

    @property
    def amount(self):
        """Gets the amount of this Transaction.  # noqa: E501

        The settled value of the transaction, denominated in the account's currency, as stated in `iso_currency_code` or `unofficial_currency_code`. Positive values when money moves out of the account; negative values when money moves in. For example, debit card purchases are positive; credit card payments, direct deposits, and refunds are negative.  # noqa: E501

        :return: The amount of this Transaction.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this Transaction.

        The settled value of the transaction, denominated in the account's currency, as stated in `iso_currency_code` or `unofficial_currency_code`. Positive values when money moves out of the account; negative values when money moves in. For example, debit card purchases are positive; credit card payments, direct deposits, and refunds are negative.  # noqa: E501

        :param amount: The amount of this Transaction.  # noqa: E501
        :type amount: float
        """

        self._amount = amount

    @property
    def account_id(self):
        """Gets the account_id of this Transaction.  # noqa: E501

        The ID of the account in which this transaction occurred.  # noqa: E501

        :return: The account_id of this Transaction.  # noqa: E501
        :rtype: str
        """
        return self._account_id

    @account_id.setter
    def account_id(self, account_id):
        """Sets the account_id of this Transaction.

        The ID of the account in which this transaction occurred.  # noqa: E501

        :param account_id: The account_id of this Transaction.  # noqa: E501
        :type account_id: str
        """

        self._account_id = account_id

    @property
    def transaction_code(self):
        """Gets the transaction_code of this Transaction.  # noqa: E501


        :return: The transaction_code of this Transaction.  # noqa: E501
        :rtype: TransactionCode
        """
        return self._transaction_code

    @transaction_code.setter
    def transaction_code(self, transaction_code):
        """Sets the transaction_code of this Transaction.


        :param transaction_code: The transaction_code of this Transaction.  # noqa: E501
        :type transaction_code: TransactionCode
        """

        self._transaction_code = transaction_code

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Transaction):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Transaction):
            return True

        return self.to_dict() != other.to_dict()
